@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Thursday 18 July 02 12:59:52 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 14:22:01 tews@debian>
  *
  * check assertions/creation conditions for behavioural invariance
  *
- * $Id: behavioural.ml,v 1.3 2002/07/18 13:43:20 tews Exp $
+ * $Id: behavioural.ml,v 1.4 2003/08/21 15:15:06 tews Exp $
  *
  *)
  
@@ -96,6 +96,8 @@ let rec pedantic_expression loc expr =
 		 assert(false)
 	  )
 
+					    (* we are in pedantic_expression *)
+
 					(* a variable *)
       | BasicExpr(TermVar(Resolved(id_rec))) -> ()
 
@@ -126,6 +128,8 @@ let rec pedantic_expression loc expr =
 	     | _ -> assert false 
 	  )
 
+					    (* we are in pedantic_expression *)
+
 				(* MethodSelection needs TypeAnnotation *)
       | MethodSelection _ ->
 	  assert(false)
@@ -158,10 +162,16 @@ let rec pedantic_expression loc expr =
 	  recurse_exp ex;
 	  List.iter (fun (mem,ids,exp) -> recurse_exp exp) variants
 
-	    (* holds for polynomial functors *)
-      | Box(typ, pred, tlist) -> recurse_exp pred
+					    (* we are in pedantic_expression *)
 
-      | Diamond(typ, pred, tlist) -> recurse_exp pred
+	    (* holds for polynomial functors *)
+      | Modality(modal,typ,pred,tlist) -> recurse_exp pred
+
+      (* DELETE
+       * | Box(typ, pred, tlist) -> recurse_exp pred
+       * 
+       * | Diamond(typ, pred, tlist) -> recurse_exp pred
+       *)
 
       | Expression form -> recurse_form form
       | TypeAnnotation(exp,typ) -> recurse_exp exp
