@@ -18,12 +18,12 @@
  *
  * Created 9.3.02 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 10:12:08 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 16:09:44 tews@debian>
  *
  * The class method pass : coreduce and friends
  * requires that feature pass has been done
  * 
- * $Id: class_methods.ml,v 1.4 2002/07/18 13:43:20 tews Exp $
+ * $Id: class_methods.ml,v 1.5 2003/08/21 15:15:06 tews Exp $
  *
  *)
 
@@ -74,6 +74,11 @@ let make_adt_suit_type_list adt carrier_subst =
 
 
 let add_iface_method cl name typ sort =
+  let _ = assert(sort = Class_Sig_Special 
+		 || sort = Class_Coreduce
+		 || sort = Class_Map
+		 || sort = Adt_Special) 
+  in
   let m_tok = {token_name = name; loc = None};
   in
   let mem = new ccsl_pre_member_class cl m_tok []
@@ -95,7 +100,7 @@ let add_invariance cl inv_name =
   let inv_type = SmartFunction( class_suit_type_list, 
 			   Function( Function(tv, Bool), Bool))
   in
-    add_iface_method cl inv_name inv_type Class_Special
+    add_iface_method cl inv_name inv_type Class_Sig_Special
 
 
 (*********************************************************
@@ -116,7 +121,7 @@ let add_bisimulation cl bisim_name =
 		Function( 
 		  Function(Product[tv1;tv2], Bool), Bool)))
   in
-    add_iface_method cl bisim_name bisim_type Class_Special
+    add_iface_method cl bisim_name bisim_type Class_Sig_Special
 
 
 (*********************************************************
@@ -137,7 +142,7 @@ let add_morphism cl morph_name =
 		Function( 
 		  Function(tv1,tv2), Bool)))
   in
-    add_iface_method cl morph_name morph_type Class_Special
+    add_iface_method cl morph_name morph_type Class_Sig_Special
 
 
 (*********************************************************
@@ -156,6 +161,59 @@ let add_coreduce cl coreduce_name =
       coreduce_type Class_Coreduce
 
 
+(*********************************************************
+ *
+ * class map
+ *
+ *)
+
+let add_class_map cl map_name =
+  (* do variance separation; 
+   * see also ccsl_adt_map_theory, ccsl_map_struct_theory, 
+   *    create_ids_with_variance
+   *)
+  let param_ids = List.map (function TypeParameter id -> id) cl#get_parameters
+  in let source_types = 
+      List.map (fun _ -> FreeTypeVariable(Type_variable.fresh())) param_ids
+  in let target_types = 
+      List.map (function id -> BoundTypeVariable(id)) param_ids
+  in let pre_pre_fun_types = 
+      Util.map3 (fun source target id -> 
+		   (Function(source, target),
+		    Logic_util.make_simple id.id_variance))
+	source_types target_types param_ids
+  in
+  let pre_fun_types = 
+    List.map
+      (fun (t,v) -> match v with
+	 | Unused
+	 | Pos -> (None, Some(t))
+	 | Neg -> 
+	     (match t with 
+		| Function(dom,codom) -> (Some( Function(codom,dom) ), None)
+		| _ -> assert(false)
+	     )
+	 | Mixed -> 
+	     (match t with 
+		| Function(dom,codom) -> (Some( Function(codom,dom) ), Some(t))
+		| _ -> assert(false)
+	     )
+	 | _ -> assert(false)
+      )
+      pre_pre_fun_types
+  in let fun_types = Logic_util.variance_flatten pre_fun_types
+  in
+    (* source/target types *)
+  let source_typ = 
+    Class(cl, List.map (fun t -> TypeArgument t) source_types)
+  in 
+  let target_typ = Self
+  in let map_type =
+      SmartFunction(fun_types, Function(source_typ, target_typ))
+  in
+    add_iface_method cl map_name map_type Class_Map
+
+
 (*********************************************************
  *
  * reduce
@@ -169,7 +227,59 @@ let add_reduce adt reduce_name =
   let reduce_type = SmartFunction( adt_suit_type_list, Function(Carrier, tv))
   in
     add_iface_method adt reduce_name
-      reduce_type Adt_Reduce
+      reduce_type Adt_Special
+
+
+(*********************************************************
+ *
+ * adt map
+ *
+ *)
+
+let add_adt_map adt map_name =
+  (* do variance separation; 
+   * see also ccsl_adt_map_theory, ccsl_map_struct_theory, 
+   *    create_ids_with_variance
+   *)
+  let param_ids = List.map (function TypeParameter id -> id) adt#get_parameters
+  in let source_types = 
+      List.map (function id -> BoundTypeVariable(id)) param_ids
+  in let target_types = 
+      List.map (fun _ -> FreeTypeVariable(Type_variable.fresh())) param_ids
+  in let pre_pre_fun_types = 
+      Util.map3 (fun source target id -> 
+		   (Function(source, target),
+		    Logic_util.make_simple id.id_variance))
+	source_types target_types param_ids
+  in
+  let pre_fun_types = 
+    List.map
+      (fun (t,v) -> match v with
+	 | Unused
+	 | Pos -> (None, Some(t))
+	 | Neg -> 
+	     (match t with 
+		| Function(dom,codom) -> (Some( Function(codom,dom) ), None)
+		| _ -> assert(false)
+	     )
+	 | Mixed -> 
+	     (match t with 
+		| Function(dom,codom) -> (Some( Function(codom,dom) ), Some(t))
+		| _ -> assert(false)
+	     )
+	 | _ -> assert(false)
+      )
+      pre_pre_fun_types
+  in let fun_types = Logic_util.variance_flatten pre_fun_types
+  in
+    (* source/target types *)
+  let source_typ = Carrier in
+  let target_typ = 
+    Adt(adt, Always, List.map (fun t -> TypeArgument t) target_types)
+  in let map_type =
+      SmartFunction(fun_types, Function(source_typ, target_typ))
+  in
+    add_iface_method adt map_name map_type Adt_Special
 
 
 (*********************************************************
@@ -189,6 +299,13 @@ let do_class cl  =
 	 add_coreduce cl coreduce_name
     );
 
+    (let map_name = Top_names.name_of_class_map cl in
+       if (cl#has_feature HasMapFeature) &&
+	 (check_for_clash loc cl map_name)
+       then
+	 add_class_map cl map_name
+    );
+
     (let inv_name = Names.name_of_private_struct_invariance cl 
      in
        if check_for_clash loc cl inv_name
@@ -212,9 +329,20 @@ let do_class cl  =
 
 
 let do_adt adt =
-  let reduce_name = Names.name_of_adt_reduce adt 
+  let loc = remove_option (adt#get_token).loc
   in
-    add_reduce adt reduce_name
+    (let reduce_name = Names.name_of_adt_reduce adt in
+       if check_for_clash loc adt reduce_name
+       then
+	 add_reduce adt reduce_name
+    );
+
+    (let map_name = Top_names.name_of_adt_map adt in
+       if (adt#has_feature HasMapFeature) &&
+	 (check_for_clash loc adt map_name)
+       then
+	 add_adt_map adt map_name
+    )
 
 
 let do_ast = function
