@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Hendrik
  *
- * Time-stamp: <Thursday 11 July 02 18:09:24 tews@ithif51>
+ * Time-stamp: <Thursday 21 August 03 15:06:33 tews@ithif51.inf.tu-dresden.de>
  *
  * type hierarchy for CCSL
  *
- * $Id: classtypes.ml,v 1.17 2002/07/18 13:43:21 tews Exp $
+ * $Id: classtypes.ml,v 1.18 2003/08/21 15:15:06 tews Exp $
  *
  *)
 
@@ -238,7 +238,10 @@ object
      * local symbol tables
      *)
 
-       (* filled in inheritance pass, retained in instanciations *)
+       (* filled in inheritance pass, retained in instanciations 
+	* contains local symbol tables of all ancestors
+	* does not contain own symbol table
+	*)
     val mutable inherited_locals :  
       ('super_class, 'member_type) top_pre_scope_type list
 
@@ -341,8 +344,7 @@ class type ['class_type, 'member_type] ccsl_pre_member_type
   =
   object 
     inherit ['class_type, 'member_type] top_pre_member_type
-    constraint 'class_type =
-	       < dump_iface : string; get_name : string; .. >
+    constraint 'class_type = < get_name : string; .. >
 
 	(* returns the true type of the method
 	 *)
@@ -535,9 +537,6 @@ class type virtual
 
     method assert_coalgebra1_type : ('class_type, 'member_type) top_pre_types
 
-(* ISAR
- *     method assert_coalgebra2_type : ('class_type, 'member_type) top_pre_types
- *)
 
       (* a complete variable declaration for the coalgebra *)
     method coalgebra_decl :
@@ -552,13 +551,6 @@ class type virtual
     method assert_coalgebra_decl :
       ('class_type, 'member_type) top_pre_theory_declaration
 
-(* ISAR
- *     method assert_coalgebra1_decl :
- * 	 ('class_type, 'member_type) top_pre_theory_declaration
- * 
- *     method assert_coalgebra2_decl :
- * 	 ('class_type, 'member_type) top_pre_theory_declaration
- *)
 
       (* coalgebra term is in ccsl_pre_theory_body_type *)
 
@@ -637,10 +629,6 @@ class type ['class_type, 'member_type] ccsl_pre_class_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-(* ISAR
- *     method get_proofs :
- * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
- *)
 
   end (* ccsl_pre_class_theory_type *)
 
@@ -692,11 +680,6 @@ class type ['class_type, 'member_type] ccsl_pre_adt_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-(* ISAR
- *     method get_proofs :
- * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
- *)
-
   end (* ccsl_pre_adt_theory_type *)
 
 
@@ -745,11 +728,6 @@ class type ['class_type, 'member_type] ccsl_pre_sig_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-(* ISAR
- *     method get_proofs :
- * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
- *)
-
   end (* ccsl_pre_sig_theory_type *)
 
 
