@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 16:36:32 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 16:09:44 tews@debian>
  *
  * adding components
  *
- * $Id: component_pass.ml,v 1.7 2002/10/28 16:33:18 tews Exp $
+ * $Id: component_pass.ml,v 1.8 2003/08/21 15:15:05 tews Exp $
  *
  *)
 
@@ -89,8 +89,8 @@ let do_adt_member_component adt v typ =
 
 let do_adt_member adt m =
   match m#get_sort with
-    | Adt_Const_Constructor | Adt_Reduce -> ()
-    | Class_Coreduce | Class_Special -> assert(false)
+    | Adt_Const_Constructor | Adt_Special -> ()
+    | Class_Coreduce | Class_Sig_Special | Class_Map -> assert(false)
     | _ -> 
 	begin
 	  iter_components Pos (do_adt_member_component adt) m#get_domain;
@@ -155,8 +155,8 @@ let do_class_member cl m =
   in
 *)
   match m#get_sort with
-    | Class_Coreduce | Class_Special -> ()
-    | Adt_Const_Constructor | Adt_Reduce -> assert(false)
+    | Class_Coreduce | Class_Map | Class_Sig_Special -> ()
+    | Adt_Const_Constructor | Adt_Special -> assert(false)
     | _ -> 
 	begin
 	  iter_components Neg (do_class_member_component cl) m#get_domain;
