@@ -18,17 +18,19 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 19 August 03 23:57:27 tews@debian>
  *
  * Feature pass for CCSL
  *
- * $Id: feature.mli,v 1.4 2002/05/03 15:01:08 tews Exp $
+ * $Id: feature.mli,v 1.5 2003/08/21 15:15:05 tews Exp $
  *
  *)
 
 
 open Classtypes;;
 
+exception Feature_error
+
   (* adds features *)
 
 val ccsl_feature_pass : Classtypes.ccsl_ast list -> unit
