@@ -18,11 +18,11 @@
  *
  * Created 11.10.01 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 14:52:55 tews@ithif51>
+ * Time-stamp: <Monday 4 August 03 23:13:41 tews@debian>
  *
  * full invariants and bisimulations
  *
- * $Id: full_liftings_theory.ml,v 1.9 2002/10/28 16:33:18 tews Exp $
+ * $Id: full_liftings_theory.ml,v 1.10 2003/08/21 15:15:04 tews Exp $
  *
  *)
 
@@ -74,11 +74,6 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-
-(* ISAR
- *     method get_proofs = []
- *)
-
     method private do_imports =
       let do_ancestor = function
 	| Resolved_renaming (anc,args,_,_,_) -> 
@@ -396,10 +391,13 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
 
     method make_body = 
       [      
-	Library(name_of_pvs_ccsl_lib, Global.get_pvs_ccsl_lib_location());
-	LibImport(name_of_pvs_ccsl_lib, 
-		  name_of_fixedpoints, 
-		  [TypeArgument(Function(Self,Bool))]);
+	(* USE prelude gfp
+	 *
+         * Library(name_of_pvs_ccsl_lib, Global.get_pvs_ccsl_lib_location());
+	 * LibImport(name_of_pvs_ccsl_lib, 
+	 * 	  name_of_fixedpoints, 
+	 * 	  [TypeArgument(Function(Self,Bool))]);
+         *)
 	self#do_imports;
         self#coalgebra_decl;
 	self#private_class_pred;
@@ -516,11 +514,6 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
 
-(* ISAR
- *     method get_proofs = []
- *)
-
-
 	(* override these two methods to get the coalgebra 
 	 * declarations right
 	 *)
@@ -891,10 +884,13 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
 
     method make_body = 
       [      
-	Library(name_of_pvs_ccsl_lib, Global.get_pvs_ccsl_lib_location());
-	LibImport(name_of_pvs_ccsl_lib, 
-		  name_of_fixedpoints, 
-		  [TypeArgument(self#rel_type)]);
+	(* USE prelude gfp
+	 *
+         * Library(name_of_pvs_ccsl_lib, Global.get_pvs_ccsl_lib_location());
+	 * LibImport(name_of_pvs_ccsl_lib, 
+	 * 	  name_of_fixedpoints, 
+	 * 	  [TypeArgument(self#rel_type)]);
+         *)
 	self#do_imports;
         (self#coalgebra1_decl);
         (self#coalgebra2_decl);
