@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 14:43:20 tews@ithif51>
+ * Time-stamp: <Thursday 21 August 03 16:01:03 tews@ithif51.inf.tu-dresden.de>
  *
  * the class for ccsl adt's and classes
  *
- * $Id: iface_class.ml,v 1.18 2002/10/28 16:33:18 tews Exp $
+ * $Id: iface_class.ml,v 1.19 2003/08/21 15:15:04 tews Exp $
  *
  *)
 
@@ -293,7 +293,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
      *)
 
     method add_member m =
-      Symbol.create_local local m#get_name (MemberSymb m);
+      Symbol.create_local self#get_local m#get_name (MemberSymb m);
       if not has_constructors && m#is_constructor 
       then has_constructors <- true;
       top_iface#add_member m
@@ -309,7 +309,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	 * contains also the own local table
 	 *)
     val mutable inherited_locals =
-      ([local] : ('super_class, 'member_type) top_pre_scope_type list)
+      ([] : ('super_class, 'member_type) top_pre_scope_type list)
 
     method get_inherited_locals = inherited_locals
 
@@ -317,7 +317,8 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
       inherited_locals <- inherited_locals @ locs
 
       (* search in the local symboltable of this class *)
-    method find_local name = Table.find_local local CCSL_ID name 
+    method find_local name = Table.find_local self#get_local CCSL_ID name 
+
 
     (* The next two functions were in top_iface before, but 
      * the symboltable is so different, that they make no sense there
@@ -339,7 +340,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	      )
 	    with Table.Not_defined -> doit rest
       in
-	doit inherited_locals
+	doit (self#get_local :: inherited_locals)
 
     (* find a member in this class
      * maybe raise Member_not_found
@@ -384,7 +385,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 
     method add_ground_type gt  = 
       assert(self#get_kind = Spec_sig);
-      Symbol.create_local local gt.id_token.token_name
+      Symbol.create_local self#get_local gt.id_token.token_name
 	(CCSL_GroundTypeSymb gt);
       (match gt.id_origin with
 	 | CCSL_GroundTypeDef _ ->
@@ -412,7 +413,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
     val mutable definitions = [] 
 
     method add_definition def =
-      self#add_member def.defined_method;
+      assert(Util.member (==) def.defined_method self#get_members);
       definitions <- definitions @ [def];
       if self#get_kind = Spec_sig then begin
 	has_own_output <- true;
@@ -933,15 +934,17 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	else
 	  all_theories
 	  
-    (*******************************************************************
-     *
-     * Dumping
+    (* DELETE
+     * (\*******************************************************************
+     *  *
+     *  * Dumping
+     *  *\)
+     * 
+     * method dump_iface =
+     *   (if instanciated then "INSTANCIATED" else "") ^
+     *   top_iface#dump_iface ^
+     *   "Parameters: " ^ (dump_list dump_parameter "| " parameters) ^ "\n"
      *)
-
-    method dump_iface =
-      (if instanciated then "INSTANCIATED" else "") ^
-      top_iface#dump_iface ^
-      "Parameters: " ^ (dump_list dump_parameter "| " parameters) ^ "\n"
       
 
     (*******************************************************************
