@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Wednesday 24 July 02 16:30:23 tews@ithif51>
+ * Time-stamp: <Monday 4 August 03 23:13:41 tews@debian>
  *
  * the ccsl interface theory
  *
- * $Id: interface_theory.ml,v 1.14 2002/09/18 15:35:03 tews Exp $
+ * $Id: interface_theory.ml,v 1.15 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -165,11 +165,6 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-(* ISAR
- *     method get_proofs = []
- *)
-
-
     method private user_imports = cl#get_iface_imports 
 
     method private component_imports = 
@@ -181,10 +176,14 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 		  then (ccsl_final_theory_name c, args) :: accu
 		  else (ccsl_loose_theory_name c, args) :: accu
 	      | Spec_adt -> 
-		  (match !output_mode with
-		     | Isa_mode -> (ccsl_adtutil_theory_name c, args) :: accu
-		     | Pvs_mode -> (ccsl_adt_theory_name c, args) :: accu
-		  )
+		  if c#has_feature BuildinFeature
+		  then
+		    accu
+		  else
+		    (match !output_mode with
+		       | Isa_mode -> (ccsl_adtutil_theory_name c, args) :: accu
+		       | Pvs_mode -> (ccsl_adt_theory_name c, args) :: accu
+		    )
 	      | Spec_sig -> 
 		  if c#has_own_output
 		  then			(* does have an own theory *)
@@ -425,10 +424,6 @@ class ['class_type, 'member_type] ccsl_pre_coadt_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-(* ISAR
- *     method get_proofs = []
- *)
-
     method make_body =
       [Import(
 	 [
@@ -506,10 +501,6 @@ object (self : 'self)
 		      
   method get_parameters = orig_parameters
 			    
-(* ISAR
- *   method get_proofs = []
- *)
-			
   method private ltype = TypeConstant((name_of_loose_type cl),Always,[])
 			   
   method private loose_args =
@@ -697,10 +688,6 @@ object (self : 'self)
 		      
   method get_parameters = orig_parameters
 			    
-(* ISAR
- *   method get_proofs = []
- *)
-			
   method private ftype = TypeConstant((name_of_final_type cl),Always,[])
 			   
   method private final_args =
@@ -881,10 +868,6 @@ object (self : 'self)
 		      
   method get_parameters = self#simple_parameters
 			    
-(* ISAR
- *   method get_proofs = []
- *)
-			
   method private ftype = TypeConstant((name_of_final_type cl),Always,[])
 			   
   method private final_args =
