@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 16:36:05 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 12:02:48 tews@debian>
  *
  * predicate and relation lifting
  *
- * $Id: lifting.ml,v 1.20 2002/10/28 16:33:18 tews Exp $
+ * $Id: lifting.ml,v 1.21 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -840,12 +840,8 @@ let rec pre_rellift
   * such that they can be applied to a (string * top_types) list,
   * where the substitution is only applied to the types
   *)
-  let subst1 = 
-    List.map (fun (v,typ) -> 
-    (v, self1_subst typ)) in
-  let subst2 = 
-    List.map (fun (v,typ) -> 
-    (v, self2_subst typ)) in
+  let subst1 = List.map (fun (v,typ) -> (v, self1_subst typ)) in
+  let subst2 = List.map (fun (v,typ) -> (v, self2_subst typ)) in
 
 (* 	 (* predicate on parameters, returns false, 
  * 	  * if the lifting for this parameter is not Equality
