@@ -18,11 +18,11 @@
  *
  * * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Tuesday 13 August 02 11:26:20 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 18:27:57 tews@debian>
  *
  * main compiler driver
  *
- * $Id: main.ml,v 1.20 2002/09/18 15:35:04 tews Exp $
+ * $Id: main.ml,v 1.21 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -47,6 +47,7 @@ open Component_pass
 open Feature
 open Class_methods
 open Resolution
+open Derive
 open Newtypecheck
 open Behavioural
 ;;
@@ -60,7 +61,8 @@ open Behavioural
  *)
 
 
-let pvs_prelude =
+let builtin_prelude = function
+  | Pvs_mode -> 
   "
    Begin EmptySig : GroundSignature
       Importing EmptyTypeDef
@@ -77,28 +79,73 @@ let pvs_prelude =
       Constructor
          null : Carrier;
          cons( car, cdr ) : [X, Carrier] -> Carrier
-   End list
-  ";;
+   End list"
+      ^ 
+      (if !old_lift 
+       then ""
+       else
+  "
 
-
-let isa_prelude = 
+   Begin lift[ X : Type ] : Adt
+      Constructor
+         bottom : Carrier;
+         up( down ) : X -> Carrier
+   End lift"
+      )
+  | Isa_mode -> 
   "
    Begin list[ X : Type ] : Adt
       Constructor
          Nil : Carrier;
          Cons( car, cdr ) : [X, Carrier] -> Carrier
-   End list
-  ";;
+   End list"
 
 
-let ccsl_prelude =
+let ccsl_prelude = function
+  | Pvs_mode -> 
+      (if !old_lift 
+       then
   "
    Begin Lift[ X : Type ] : Adt
       Constructor
          bot : Carrier;
          up( down ) : X -> Carrier
    End Lift
+  "
+       else ""
+      ) ^
+  "
+   Begin Coproduct[ X : Type, Y : Type ] : Adt
+      Constructor
+         in1(out1) : X -> Carrier;
+         in2(out2) : Y -> Carrier;
+   End Coproduct
    
+   Begin Unit : Adt
+      Constructor
+         unit : Carrier;
+   End Unit
+  "
+  | Isa_mode ->
+      (if !old_lift 
+       then
+  "
+   Begin Lift[ X : Type ] : Adt
+      Constructor
+         bot : Carrier;
+         up( down ) : X -> Carrier
+   End Lift
+  "
+       else
+  "
+   Begin lift[ X : Type ] : Adt
+      Constructor
+         bottom : Carrier;
+         up( down ) : X -> Carrier
+   End lift
+  "
+      ) ^
+  "
    Begin Coproduct[ X : Type, Y : Type ] : Adt
       Constructor
          in1(out1) : X -> Carrier;
@@ -113,12 +160,12 @@ let ccsl_prelude =
 
 
 let output_prelude () =
-  print_endline "PVS specific prelude:";
-  print_endline pvs_prelude;
-  print_endline "Isabelle/HOL specific prelude:";
-  print_endline isa_prelude;
-  print_endline "Common prelude:";
-  print_endline ccsl_prelude;
+  print_endline "PVS prelude:";
+  print_endline (builtin_prelude Pvs_mode);
+  print_endline (ccsl_prelude Pvs_mode);
+  print_endline "Isabelle/HOL prelude:";
+  print_endline (builtin_prelude Isa_mode);
+  print_endline (ccsl_prelude Isa_mode);
   exit 0
 
 
@@ -146,6 +193,10 @@ let options =
     ("-isa",
      Arg.Unit (fun () -> output_mode := Isa_mode),
      "Set output mode to Isabelle");
+    ("-old-lift",
+     Arg.Set old_lift,
+     "Use backward compatible prelude with Lift"
+    );
     ("-output-prelude",
      Arg.Unit output_prelude,
      "Output prelude"
@@ -186,7 +237,6 @@ let options =
      \n          8 - Resolution comments\
      \n         16 - Inheritance comments\
      \n         32 - Typecheck comments\
-     \n         64 - Print Syntax tree\
      \n        128 - Print Symbol table on unknown identifier\
      \n        256 - Apply debug_level also to prelude\
      \n        512 - print information about unification\
@@ -239,8 +289,8 @@ let options =
      Arg.Set(dependent_assertions),
      "Make each assertions dependent on the previous ones");
     ("-fixedpointlib",
-     Arg.String (set_pvs_ccsl_lib_location),
-     "Directory for the fixedpoint library (PVS only)")
+     Arg.String (fun s -> ()),
+     "No effect; present only for backward compatibility")
   ];;
 
 
@@ -292,15 +342,10 @@ let ccsl_parse_prelude () =
   let _ = parsing_prelude := true in
   let _ = parsing_builtin_prelude := true in
   let _ = Abstract_lexer.initialize "Backend specific prelude" in
-  let pvs_p_ast = 
-    parse_prelude_part 
-	(match !output_mode with
-	   | Pvs_mode -> pvs_prelude 
-	   | Isa_mode -> isa_prelude)
-  in
+  let pvs_p_ast = parse_prelude_part (builtin_prelude !output_mode) in
   let _ = parsing_builtin_prelude := false in
   let _ = Abstract_lexer.initialize "CCSL prelude" in
-  let ccsl_p_ast = parse_prelude_part ccsl_prelude in
+  let ccsl_p_ast = parse_prelude_part (ccsl_prelude !output_mode) in
   let _ = parsing_prelude := false 
   in
     pvs_p_ast @ ccsl_p_ast;;
@@ -328,8 +373,10 @@ let ccsl_parse_file filename =
     end
 
 
-let ccsl_dump ast =
-  dump_top_ast (ast : ccsl_ast list);;
+(* DELETE
+ * let ccsl_dump ast =
+ *   dump_top_ast (ast : ccsl_ast list);;
+ *)
 
 
 let ccsl_selected_classes_filter ast =
@@ -433,15 +480,22 @@ let do_ccsl_ast ast =
   print_verbose "*** Ccsl Class Methods ***";
   ccsl_class_methods_pass ast;
 
-  print_verbose( "*** Ccsl Resolution (" ^
+  print_verbose( "*** Ccsl Resolution/Typecheck (" ^
 		 (string_of_int (Type_variable.number_of_free_variables ())) ^
 		 ")  ***");
-  ccsl_resolution_pass (ast); 
+  ccsl_resolution_typecheck_pass ast;
 
-  print_verbose( "*** Ccsl_typecheck (" ^
-		 (string_of_int (Type_variable.number_of_free_variables ())) ^
-		 ")  ***");
-  ccsl_typecheck_class_pass (ast); 
+  (* DELETE 
+   * print_verbose( "*** Ccsl Resolution (" ^
+   * 		 (string_of_int (Type_variable.number_of_free_variables ())) ^
+   * 		 ")  ***");
+   * ccsl_resolution_pass (ast); 
+   * 
+   * print_verbose( "*** Ccsl_typecheck (" ^
+   * 		 (string_of_int (Type_variable.number_of_free_variables ())) ^
+   * 		 ")  ***");
+   * ccsl_typecheck_class_pass (ast); 
+   *)
 
   print_verbose( "*** Ccsl_typecheck done (" ^
 		 (string_of_int (Type_variable.number_of_free_variables ())) ^
@@ -459,10 +513,12 @@ let do_ccsl_ast ast =
     else
       ast 
   in
-  let _ = (if debug_level _DEBUG_DUMP_SYNTAX_TREE
-	   then
-	     print_string (ccsl_dump (p_ast)))
-  in
+  (* DELETE
+   * let _ = (if debug_level _DEBUG_DUMP_SYNTAX_TREE
+   * 	   then
+   * 	     print_string (ccsl_dump (p_ast)))
+   * in
+   *)
   let _ = print_verbose "*** Ccsl_theory_list ***" in
   let _ = ccsl_output_theories (ccsl_theory_list p_ast) in
   let _ = print_verbose ("*** file  done ***")
@@ -511,7 +567,17 @@ let do_ccsl_prelude () =
       assert( Symbol.nesting_size() = 1 )
       
 
-
+let fatal_exception = function
+  | Parsing.Parse_error 
+  | Abstract_lexer.Include_error
+  | Update_Method_Error
+  | Inheritance_error
+  | Variance_error
+  | Feature_error
+  | Resolution_error
+  | Typecheck_error
+  | PedanticViolation -> false
+  | _ -> true
 
 
 let do_ccsl_file file = 
@@ -530,30 +596,31 @@ let do_ccsl_file file =
       ignore(Symbol.close_block())
   with
     | exc -> 
-	(match exc with
-	   | Assert_failure (src_file, start_char, end_char) ->
-	       print_error (
-		 "Assertion in file: " ^ file ^
-		 (match !output_mode with
-		    | Pvs_mode -> " (pvs_mode)"
-		    | Isa_mode -> " (isa_mode)") ^
-		 "\nSee " ^ src_file ^ ", char " ^
-		 (string_of_int start_char) ^ "-" ^
-		 (string_of_int end_char) ^ "\n\n");
-	       raise exc;
-	   | Internal_error ->
-	       print_error (
-		 "Internal error in file: " ^ file ^
-		 "\n\n");
-	       raise exc;
+	if fatal_exception exc then
+	  (match exc with
+	     | Assert_failure (src_file, start_char, end_char) ->
+		 print_error (
+		   "Assertion in file: " ^ file ^
+		   (match !output_mode with
+		      | Pvs_mode -> " (pvs_mode)"
+		      | Isa_mode -> " (isa_mode)") ^
+		   "\nSee " ^ src_file ^ ", char " ^
+		   (string_of_int start_char) ^ "-" ^
+		   (string_of_int end_char) ^ "\n\n");
+		 raise exc;
+	     | Internal_error ->
+		 print_error (
+		   "Internal error in file: " ^ file ^
+		   "\n\n");
+		 raise exc;
 					(* catch all *)
-	   | exc -> 
-	       print_error ("Exception \n" ^
-			    (Printexc.to_string exc) ^
-			    "\n thrown in " ^ 
-			    file ^ "\n\n");
-	       raise exc;
-	)
+	     | exc -> 
+		 print_error ("Exception \n" ^
+			      (Printexc.to_string exc) ^
+			      "\n thrown in " ^ 
+			      file ^ "\n\n");
+		 raise exc;
+	  )
 
 
 ;;
