@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 20:02:34 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Wednesday 20 August 03 16:06:41 tews@debian>
  *
  * The class for ccsl constructors, attributes and methods
  *
- * $Id: member_class.ml,v 1.15 2002/05/22 13:42:41 tews Exp $
+ * $Id: member_class.ml,v 1.16 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -43,7 +43,7 @@ class ['class_type, 'member_type] ccsl_pre_member_class
       as top_member
 
     constraint 'class_type = 
-	       < dump_iface : string; get_name : string; .. >
+	       < get_name : string; .. >
 
     (*******************************************************************
      * 
@@ -64,9 +64,10 @@ class ['class_type, 'member_type] ccsl_pre_member_class
 
 	| Adt_Accessor 
 	| Adt_Recognizer 
-	| Adt_Reduce
+	| Adt_Special
 	| Class_Coreduce 
-	| Class_Special
+	| Class_Map
+	| Class_Sig_Special
 
 	| GroundTerm
 	| InfixGroundTerm
