@@ -18,11 +18,11 @@
  *
  * Created 19.5.02 by Hendrik
  *
- * Time-stamp: <Thursday 18 July 02 13:01:26 tews@ithif51>
+ * Time-stamp: <Monday 4 August 03 10:50:23 tews@debian>
  *
  * The class for ccsl constructors, attributes and methods
  *
- * $Id: member_class.mli,v 1.3 2002/07/18 13:43:22 tews Exp $
+ * $Id: member_class.mli,v 1.4 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -44,7 +44,12 @@ object
 
     (* use of Symbol in rename_member spoils the typing *)
   constraint 'class_type = <get_local : ccsl_scope_type; .. >
-  constraint 'member_type = <get_name : string; ..>
+
+  (* DELETE
+   * 
+   * constraint 'member_type = <get_name : string; ..>
+   *)
+
 end
       
 
