@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Jan
  *
- * Time-stamp: <Tuesday 16 July 02 10:15:44 tews@ithif51>
+ * Time-stamp: <Monday 4 August 03 23:13:41 tews@debian>
  *
  * Liftings and invariants
  *
- * $Id: methodinv_theory.ml,v 1.13 2002/07/18 13:43:22 tews Exp $
+ * $Id: methodinv_theory.ml,v 1.14 2003/08/21 15:15:03 tews Exp $
  *
  *)
 
@@ -71,10 +71,6 @@ class ['class_type, 'member_type] ccsl_pre_method_idtype_adt
 
     method get_parameters = []
 
-(* ISAR
- *     method get_proofs = []
- *)
-
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
 
@@ -392,10 +388,6 @@ class ['class_type, 'member_type] ccsl_pre_method_lift_theory
 		     )))))
        
                           
-(* ISAR
- *     method get_proofs = []
- *)
-
     method make_body =
       [ Import(
           (ccsl_interface_theory_name cl, self#simple_arguments) ::
@@ -485,10 +477,6 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_rewrite_theory
                                
      initializer top_theory#override_file_name (ccsl_class_file_name cl)
        
-(* ISAR
- * 	method get_proofs = []
- *)
-                           
      (* this gets overriden in derived classes to specialize
       * this class for private or public invariance
       *)
@@ -877,10 +865,6 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
        
      method get_name = ccsl_method_invariance_inherit_name cl
 			 
-(* ISAR
- * 	method get_proofs = []
- *)
-                           
      (* this gets overriden in derived classes to specialize
       * this class for private or public invariance
       *)
@@ -1313,8 +1297,8 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
 	  name_of_method_id;
 	  name_of_greatest_invariance cl;
 	  name_of_h_gi;
-	  name_of_box cl;
-	  name_of_diamond cl;
+	  name_of_modal Henceforth cl;
+	  name_of_modal Eventually cl;
 	]
        )
 
@@ -1322,7 +1306,8 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
  * 	initializer name_of_list <- create_one_id ns self#list_type
  *)
 
-     method private diamond_term = Term(name_of_diamond cl, Always, []) 
+     method private diamond_term = 
+       Term(name_of_modal Eventually cl, Always, []) 
 
      val p_pred = Expression(ConstantPredicate("P")) 
      val q_pred = Expression(ConstantPredicate("Q")) 
@@ -1333,7 +1318,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_box cl, Always, []),
+	     Term(name_of_modal Henceforth cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -1345,7 +1330,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_diamond cl, Always, []),
+	     Term(name_of_modal Eventually cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -1370,7 +1355,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        let y = create_one_id sub_ns Self in
        let y_term = Term(y, Always, []) in
 	 Defn(
-	   name_of_box cl,
+	   name_of_modal Henceforth cl,
 	   [[Declared(name_of_coalgebra, self#coalgebra_type)];
 	    [Undeclared(l, self#list_type)];
 	    [Declared("P",pred_type)]],
@@ -1422,7 +1407,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        let x : string = fst(List.nth vars 0) in
        let y : string = fst(List.nth vars 1) in
 	 Defn(
-	   name_of_diamond cl,
+	   name_of_modal Eventually cl,
 	   [[Declared(name_of_coalgebra, self#coalgebra_type)];
 	    [Undeclared(l, self#list_type)];
 	    [Declared("P",pred_type)]],
@@ -1749,10 +1734,6 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
                                
      initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-(* ISAR
- * 	method get_proofs = []
- *)
-			 
      method make_body =
        [ 
 	 Import([ccsl_method_invariance_rewrite_name cl, 
@@ -1844,7 +1825,7 @@ class ['class_type, 'member_type] ccsl_pre_box_inherit_theory
 	 Application(
 	   Application(
 	     Application(
-	       Term(name_of_box cl,Always,[]), 
+	       Term(name_of_modal Henceforth cl,Always,[]), 
 	       coalgebra_term),
 	     l_term),
 	   p_term),
@@ -1855,7 +1836,7 @@ class ['class_type, 'member_type] ccsl_pre_box_inherit_theory
 	 Application(
 	   Application(
 	     Application(
-	       Term(name_of_box acl,Always,[]),
+	       Term(name_of_modal Henceforth acl,Always,[]),
 	       Application(Term(super_access_method(acl),
 				Always,[]), 
 			   coalgebra_term)),
@@ -1935,10 +1916,6 @@ object (self : 'self)
       step_constructor_declarations ns cl;
     ]
   
-(* ISAR
- *   method get_proofs = []
- *)
-
 end (* ccsl_pre_step_adt *)
 
 class ccsl_step_adt cl = 
@@ -1978,8 +1955,8 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 	  name_of_coalgebra;
 	  "P";
 	  name_of_method_id;
-	  name_of_box cl;
-	  name_of_diamond cl;
+	  name_of_modal Henceforth cl;
+	  name_of_modal Eventually cl;
 	]
        )
 
@@ -2004,7 +1981,8 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 
      method private trans_term = Term(name_of_transition,Never,[])
 
-     method private diamond_term = Term(name_of_diamond cl, Always, []) 
+     method private diamond_term = 
+       Term(name_of_modal Eventually cl, Always, []) 
 
      val q_pred = Expression(ConstantPredicate("Q")) 
      val pred_type = Function(Self, Bool)
@@ -2013,7 +1991,7 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_box cl, Always, []),
+	     Term(name_of_modal Henceforth cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -2510,11 +2488,6 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 	 )
 		       
 			 
-	       
-(* ISAR
- * 	method get_proofs = []
- *)
-			 
      method make_body =
        [	    
 	 Import([(ccsl_box_theory_name cl, 
