@@ -18,25 +18,34 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 21 May 02 18:41:21 tews@ithif51>
  *
  * Liftings and invariance
  *
- * $Id: methodinv_theory.mli,v 1.4 2002/01/23 16:00:17 tews Exp $
+ * $Id: methodinv_theory.mli,v 1.6 2002/05/22 13:42:41 tews Exp $
  *
  *)
 
 open Classtypes
 	 
+class ccsl_method_idtype_adt :
+  ccsl_iface_type -> ccsl_class_theory_type
+			 		    
 class ccsl_method_lift_theory :
   ccsl_iface_type -> ccsl_class_theory_type
 			 		    
 class ccsl_method_invariance_rewrite_theory :
   ccsl_iface_type -> ccsl_class_theory_type
 
+class ccsl_method_invariance_inherit_theory :
+  ccsl_iface_type -> ccsl_class_theory_type
+
 class ccsl_box_theory :			    
   ccsl_iface_type -> ccsl_class_theory_type
 
+class ccsl_box_inherit_theory :			    
+  ccsl_iface_type -> ccsl_class_theory_type
+
 class ccsl_step_adt : 
   ccsl_iface_type -> ccsl_adt_theory_type
 
@@ -48,5 +57,6 @@ class ccsl_path_theory :
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
 
