@@ -18,11 +18,11 @@
  *
  * Created 16.03.00 by Jan
  *
- * Time-stamp: <Friday 17 May 02 12:33:18 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 16:11:32 tews@ithif51>
  *
  * predicate and relation lifting
  *
- * $Id: morphism.ml,v 1.14 2002/05/22 13:42:41 tews Exp $
+ * $Id: morphism.ml,v 1.15 2002/07/18 13:43:23 tews Exp $
  *
  *)
 
@@ -499,16 +499,14 @@ let coalgebra_morphism
     assert(count_self_args anc_arguments = 0);
     Formula(
       Application(
-      	Application(
+      	SmartApplication(
 	  Term(anc_morphism anc, Always, self_type_arguments @ anc_arguments),
-	  Tuple(
 	    [
 	      Application(Term(super_access_method anc, Always, []),
 			  coalgebra1);
 	      Application(Term(super_access_method anc, Always, []),
 			  coalgebra2)
 	    ]
-	  )
 	),
       	morphism
       )
