@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 15 July 02 15:58:04 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 14:11:44 tews@debian>
  *
  * strings for ccsl translation
  *
- * $Id: names.ml,v 1.12 2002/07/18 13:43:23 tews Exp $
+ * $Id: names.ml,v 1.13 2003/08/21 15:15:02 tews Exp $
  *
  *)
 
@@ -368,15 +368,25 @@ let name_of_greatest_invariance cl =
 
 let name_of_h_gi = "H_gi"
 
-let name_of_box cl = 
-  match !output_mode with
-    | Pvs_mode -> "box"
-    | Isa_mode -> cl#get_name ^ "_box"
+let name_of_modal modal cl = 
+  match !output_mode,modal with
+    | Pvs_mode, Henceforth -> "box"
+    | Isa_mode, Henceforth -> cl#get_name ^ "_box"
+    | Pvs_mode, Eventually -> "diamond"
+    | Isa_mode, Eventually -> cl#get_name ^ "_diamond"
 
-let name_of_diamond cl = 
-  match !output_mode with
-    | Pvs_mode -> "diamond"
-    | Isa_mode -> cl#get_name ^ "_diamond"
+
+(* DELETE
+ * let name_of_box cl = 
+ *   match !output_mode with
+ *     | Pvs_mode -> "box"
+ *     | Isa_mode -> cl#get_name ^ "_box"
+ * 
+ * let name_of_diamond cl = 
+ *   match !output_mode with
+ *     | Pvs_mode -> "diamond"
+ *     | Isa_mode -> cl#get_name ^ "_diamond"
+ *)
 
 
 let name_of_monotonic = 
