@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 15 July 02 15:54:51 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 14:12:34 tews@debian>
  *
  * strings for ccsl translation
  *
- * $Id: names.mli,v 1.12 2002/07/18 13:43:23 tews Exp $
+ * $Id: names.mli,v 1.13 2003/08/21 15:15:02 tews Exp $
  *
  *)
 
@@ -273,9 +273,14 @@ val name_of_greatest_invariance: <get_name : string; .. > -> string
 
 val name_of_h_gi: string
 
-val name_of_box: <get_name : string; .. > -> string
+val name_of_modal: 
+  Top_variant_types.top_modality_type -> <get_name : string; .. > -> string
 
-val name_of_diamond: <get_name : string; .. > -> string
+(* DELETE
+ * val name_of_box: <get_name : string; .. > -> string
+ * 
+ * val name_of_diamond: <get_name : string; .. > -> string
+ *)
 
 val name_of_admissible: string
 
