@@ -18,21 +18,21 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 17:35:25 tews@debian>
  *
  * Typechecking with unification
  *
- * $Id: newtypecheck.mli,v 1.3 2002/05/03 15:01:12 tews Exp $
+ * $Id: newtypecheck.mli,v 1.4 2003/08/21 15:15:02 tews Exp $
  *
  *)
 
 open Classtypes
 ;;
 
-exception Typecheck_error
-  
-val ccsl_typecheck_class_pass : Classtypes.ccsl_ast list -> unit
 
+(* val ccsl_typecheck_class_pass : Classtypes.ccsl_ast list -> unit *)
+
+val ccsl_resolution_typecheck_pass : Classtypes.ccsl_ast list -> unit
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
