@@ -18,11 +18,11 @@
  *
  * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Wednesday 18 September 02 12:39:02 tews@ithif51>
+ * Time-stamp: <Thursday 21 August 03 14:37:15 tews@ithif51.inf.tu-dresden.de>
  *
  * Utility functions for ccsl parser
  *
- * $Id: parser.ml,v 1.27 2002/09/18 15:35:04 tews Exp $
+ * $Id: parser.ml,v 1.28 2003/08/21 15:15:02 tews Exp $
  *
  *)
 
@@ -545,7 +545,7 @@ let do_adt_end startloc end_id =
  *   in
  *   let reduce_mem = new ccsl_pre_member_class (ciface()) reduce_tok []
  * 			(Product[]) reduce_type
- * 			NoVisibility Adt_Reduce
+ * 			NoVisibility Adt_Special
  *   in
  *     add_member_to_iface reduce_mem;
  *)
@@ -968,6 +968,7 @@ let do_definition token d_type equation =
 	      string_of_ccsl_formula f)
 	 | _ -> ()
       );
+    add_member_to_iface m;
     (ciface())#add_definition def
   
 
