@@ -18,11 +18,11 @@
  *
  * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 21:00:10 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Tuesday 13 August 02 16:32:33 tews@ithif51>
  *
  * Utility functions for ccsl parser
  *
- * $Id: parser.mli,v 1.14 2002/05/22 13:42:43 tews Exp $
+ * $Id: parser.mli,v 1.15 2002/09/18 15:35:04 tews Exp $
  *
  *)
 
@@ -182,24 +182,26 @@ val do_qualified_type_id :
                              * location_type option * token_type -> 
       ccsl_input_types
 
-    (* do a constant class constructor *)
-val do_const_class_constructor : token_type ->  ccsl_input_types -> unit 
+    (* do a class constructor *)
+val do_class_constructor : token_type -> ccsl_input_types -> unit 
 
-    (* do a parametrized class constructor *)
-val do_var_class_constructor : token_type -> ccsl_input_types -> ccsl_input_types -> unit 
+(* DELETE
+ *     (* do a parametrized class constructor *)
+ * val do_var_class_constructor : token_type -> ccsl_input_types -> ccsl_input_types -> unit 
+ * 
+ *)
 
     (* do a attribute *)
-val do_attribute : token_type -> ccsl_input_types -> ccsl_input_types -> unit 
+val do_attribute : token_type -> ccsl_input_types -> unit 
 
     (* do a method *)
-val do_method : token_type ->  ccsl_input_types -> ccsl_input_types -> unit 
+val do_method : token_type ->  ccsl_input_types -> unit 
 
     (* do class imports *)
 val do_class_imports : ccsl_importing_type list -> unit
 
     (* do a definitional extension *)
-val do_definition : 
-  token_type -> ccsl_input_types -> ccsl_input_types -> ccsl_assertion -> unit
+val do_definition : token_type -> ccsl_input_types -> ccsl_assertion -> unit
 
     (* do assertion imports, var declarations *)
 val do_assertion_start : 
@@ -244,18 +246,19 @@ val do_id_declaration :
    (* creates an optional selfvar "x", if nothing was declared *)
 val do_selfvar_default : unit -> token_type * ccsl_input_types
 
-
-    (* doing the constant adt constructor, name, accessor list, 
-     * codomain type (must be `Carrier)
-     *)
-val do_const_adt_constructor : token_type -> token_type list -> 
-  ccsl_input_types -> unit
-
+(* DELETE
+ *     (* doing the constant adt constructor, name, accessor list, 
+ * 	* codomain type (must be `Carrier)
+ * 	*)
+ * val do_const_adt_constructor : token_type -> token_type list -> 
+ *   ccsl_input_types -> unit
+ * 
+ *)
     (* doing the general adt constructor, name, accessor list, 
      * domain type, codomain type (must be `Carrier)
      *)
-val do_var_adt_constructor : token_type -> token_type list -> 
-  ccsl_input_types -> ccsl_input_types -> unit
+val do_adt_constructor : token_type -> token_type list -> 
+  ccsl_input_types -> unit
 
     (* give `Self back, if we are parsing a class *)
 val self_action : location_type -> ccsl_input_types
