@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 21:12:15 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Wednesday 20 August 03 18:31:46 tews@debian>
  *
  * Resolution pass for CCSL
  *
- * $Id: resolution.ml,v 1.16 2002/07/18 13:43:24 tews Exp $
+ * $Id: resolution.ml,v 1.17 2003/08/21 15:15:01 tews Exp $
  *
  *)
 
@@ -133,7 +133,7 @@ let check_method_label cl token =
       undefined_method cl token (remove_option token.loc)
 
 
-let rec do_basic_expr ccl loc = function  
+let rec resolve_basic_expr ccl loc = function  
   | TermVar(Resolved _ ) -> assert false
   | TermVar(Unresolved token) ->
       let symb = 
@@ -243,7 +243,7 @@ let rec do_basic_expr ccl loc = function
 
 	  (* do one branch of a CCSL_Case *)
 and do_variant ccl loc adt tvars (const, args, ex) =
-  let recurse_exp = do_expression ccl loc in
+  let recurse_exp = resolve_expression ccl loc in
   let token = match const with 
     | Unresolved t -> t
     | _ -> assert(false) in
@@ -304,12 +304,12 @@ and do_variant ccl loc adt tvars (const, args, ex) =
     ignore(Symbol.close_block());
     (Resolved member, args, nex)
 
-and do_expression ccl loc expr = 
-  let recurse_exp = do_expression ccl loc in
-  let recurse_form = do_formula ccl loc in
+and resolve_expression ccl loc expr = 
+  let recurse_exp = resolve_expression ccl loc in
+  let recurse_form = resolve_formula ccl loc in
     match expr with
-      | ExprLoc(ex,loc) -> ExprLoc(do_expression ccl loc ex, loc)
-      | BasicExpr bexpr -> do_basic_expr ccl loc bexpr
+      | ExprLoc(ex,loc) -> ExprLoc(resolve_expression ccl loc ex, loc)
+      | BasicExpr bexpr -> resolve_basic_expr ccl loc bexpr
       | TypedTerm(Term _, typ) ->
 	  dr "typed groundterm";
 	  expr	  
@@ -341,6 +341,7 @@ and do_expression ccl loc expr =
 	      ignore(Symbol.close_block ());
 	      Abstraction(decl_list, new_ex)
 	  end
+						(* we are in do_expression *)
       | Application(ex1,ex2) -> 
 	  dr "Application";
 	  Application(recurse_exp ex1, recurse_exp ex2)
@@ -390,6 +391,8 @@ and do_expression ccl loc expr =
 		| InstAdtSymb _ 
 		  -> assert(false)
 	     )
+						(* we are in do_expression *)
+
 					(* no other InfixApplication *)
       | InfixApplication _ -> 
 	  assert(false)
@@ -421,6 +424,7 @@ and do_expression ccl loc expr =
 	  let nex = recurse_exp ex in
 	    List.iter (fun _ -> ignore(Symbol.close_block())) decl_list;
 	    Let(ndecl_list, nex)
+						(* we are in do_expression *)
       | If(conds,ex) -> 
 	  dr "If";
 	  If( List.map (fun (f,ex) -> (recurse_form f, recurse_exp ex)) conds,
@@ -464,8 +468,9 @@ and do_expression ccl loc expr =
 	  in 
 	    CCSL_Case(nex, nvariants)
 
-      | Box(typ,pred,tlist) ->
-	  let _ = dr "Box" in
+						(* we are in do_expression *)
+      | Modality(modal,typ,pred,tlist) ->
+	  let _ = dr "Modality" in
 	  let cl = match typ with
 	    | Self -> ccl
 	    | Class(cl,_) -> cl
@@ -477,23 +482,41 @@ and do_expression ccl loc expr =
 		   | None -> tl) 
 		tlist [];
 	  in
-	    Box(typ, recurse_exp pred, ntlist)
+	    Modality(modal, typ, recurse_exp pred, ntlist)
 
-      | Diamond(typ,pred,tlist) ->
-	  let _ = dr "Diamond" in
-	  let cl = match typ with
-	    | Self -> ccl
-	    | Class(cl,_) -> cl
-	    | _ -> assert(false) 
-	  in let ntlist = 
-	      List.fold_right 
-		(fun t tl -> match check_method_label cl t with 
-		   | Some t' -> t' :: tl
-		   | None -> tl) 
-		tlist [];
-	  in
-	    Diamond(typ, recurse_exp pred, ntlist)
+      (* DELETE
+       * | Box(typ,pred,tlist) ->
+       * 	  let _ = dr "Box" in
+       * 	  let cl = match typ with
+       * 	    | Self -> ccl
+       * 	    | Class(cl,_) -> cl
+       * 	    | _ -> assert(false) 
+       * 	  in let ntlist = 
+       * 	      List.fold_right 
+       * 		(fun t tl -> match check_method_label cl t with 
+       * 		   | Some t' -> t' :: tl
+       * 		   | None -> tl) 
+       * 		tlist [];
+       * 	  in
+       * 	    Box(typ, recurse_exp pred, ntlist)
+       * 
+       * | Diamond(typ,pred,tlist) ->
+       * 	  let _ = dr "Diamond" in
+       * 	  let cl = match typ with
+       * 	    | Self -> ccl
+       * 	    | Class(cl,_) -> cl
+       * 	    | _ -> assert(false) 
+       * 	  in let ntlist = 
+       * 	      List.fold_right 
+       * 		(fun t tl -> match check_method_label cl t with 
+       * 		   | Some t' -> t' :: tl
+       * 		   | None -> tl) 
+       * 		tlist [];
+       * 	  in
+       * 	    Diamond(typ, recurse_exp pred, ntlist)
+       *)
 
+						(* we are in do_expression *)
       | Expression form -> 
 	  dr "Expression";
 	  Expression(recurse_form form)
@@ -517,11 +540,11 @@ and do_expression ccl loc expr =
       | Comprehension _ ->
 	  assert(false)
 	
-and do_formula ccl loc formula =
-  let recurse_exp = do_expression ccl loc in
-  let recurse_form = do_formula ccl loc in
+and resolve_formula ccl loc formula =
+  let recurse_exp = resolve_expression ccl loc in
+  let recurse_form = resolve_formula ccl loc in
     match formula with
-      | FormLoc(f,loc) -> FormLoc(do_formula ccl loc f, loc)
+      | FormLoc(f,loc) -> FormLoc(resolve_formula ccl loc f, loc)
       | True -> formula
       | False -> formula
       | Not f -> 
@@ -542,6 +565,7 @@ and do_formula ccl loc formula =
       | Equal(ex_a,ex_b) -> 
 	  dr "Equal";
 	  Equal(recurse_exp ex_a, recurse_exp ex_b)
+						     (* we are in do_formula *)
       | Forall(quant_list, f) -> 
 	  begin
 	    dr "Forall";
@@ -569,6 +593,8 @@ and do_formula ccl loc formula =
 	  dr "Obseq";
 	  Obseq(t, recurse_exp ex1, recurse_exp ex2)
 	  
+						     (* we are in do_formula *)
+
 					(* not in ccsl_input_formulas *)
       | MetaImplies _
       | MetaForall _
@@ -580,186 +606,190 @@ and do_formula ccl loc formula =
 
 
 
-let do_assertion ccl assertion = 
-  let _ = d ("  * Resolve assertion " ^ assertion.assertion_name.token_name) 
-  in
-    if not assertion.is_generated
-    then 				(* user assertion *)
-      match assertion.assertion_formula with
-	| Symbolic (FormLoc(formula,loc)) -> 
-	    begin
-	      ignore(Symbol.start_block());
-	      (match assertion.self_variable with
-		 | None -> ()
-		 | Some id_rec -> Symbol.create_var id_rec
-	      );
-	      List.iter Symbol.create_var assertion.free_variables;
-	      let new_form = do_formula ccl loc formula 
-	      in
-		ignore(Symbol.close_block());
-		assertion.assertion_formula <- Symbolic(FormLoc(new_form,loc))
-	    end
-	  
-	| Symbolic _ -> assert(false)
-	| Pvs_String _
-	| Isa_String _ -> ()
-
-
-(* Process a definition in a ground signature or in a class
- * 
- * From the parser the definition comes in as a formula, which 
- * should better be an equation.
- * From the left hand side of the equation I extract variable declarations, 
- * by matching these variables against the declared type.
- * After that the left hand side is thrown away, the extracted variables 
- * are stored in the definition record and the right hand side is wrapped
- * in a TypeAnnotation to remember its supposed type
+(* 
+ * let do_assertion ccl assertion = 
+ *   let _ = d ("  * Resolve assertion " ^ assertion.assertion_name.token_name) 
+ *   in
+ *     if not assertion.is_generated
+ *     then 				(\* user assertion *\)
+ *       match assertion.assertion_formula with
+ * 	| Symbolic (FormLoc(formula,loc)) -> 
+ * 	    begin
+ * 	      ignore(Symbol.start_block());
+ * 	      (match assertion.self_variable with
+ * 		 | None -> ()
+ * 		 | Some id_rec -> Symbol.create_var id_rec
+ * 	      );
+ * 	      List.iter Symbol.create_var assertion.free_variables;
+ * 	      let new_form = do_formula ccl loc formula 
+ * 	      in
+ * 		ignore(Symbol.close_block());
+ * 		assertion.assertion_formula <- Symbolic(FormLoc(new_form,loc))
+ * 	    end
+ * 	  
+ * 	| Symbolic _ -> assert(false)
+ * 	| Pvs_String _
+ * 	| Isa_String _ -> ()
  *)
 
-let do_symbolic_definition iface def =
-  let def_eq = match def.definition with
-    | Symbolic eq -> eq
-    | _ -> assert(false)
-  in let mem = def.defined_method in
-				(* create the block for this equation *)
-  let local_block = Symbol.start_block() in
-  let _ = d ("  * Resolve definition " ^ def.defined_method#get_name) in
 
-					(* create local type parameters *)
-  let _ = List.iter (function TypeParameter id_rec ->
-		       Symbol.create_type_parameter id_rec) 
-	    mem#get_local_parameters
-  in					(* extract left and right hand sides *)
-  let left, right, right_loc = 
-    match def_eq with
-      | FormLoc(Equal(left, ExprLoc(right,right_loc)), _)
-	  -> left,right,right_loc
-      | _ -> 
-	  begin
-	    error_message (get_form_loc def_eq)
-	      "Definition not in form of an equation.";
-	    raise Resolution_error
-	  end
-		(* recursively extract variables from the left hand side 
-		 * take care to handle cases like
-		 *   f = ...
-		 *   f x y = ...
-		 *   f (x,y) (a,b) = ...
-		 *   (x + y) (a,b) = ...
-		 *)
-  in let rec get_args accu = function
-					(* base case normal application *)
-    | ExprLoc(Application(
-		ExprLoc(BasicExpr(TermVar(Unresolved defname)),_),
-		args),_) 
-	when defname.token_name = mem#get_name ->
-	args :: accu
-					(* base case def =  *)
-    | ExprLoc(BasicExpr(TermVar(Unresolved defname)),_)
-	when defname.token_name = mem#get_name 
-	  ->
-	accu
-					(* base case with infixes *)
-    | ExprLoc(InfixApplication(leftex, _, Unresolved op, rightex), loc) 
-	when op.token_name = mem#get_name ->
-	(match mem#get_full_type with
-	   | Function(Product [_;_], _) -> 
-	       ExprLoc(Tuple([leftex;rightex]), loc) :: accu
-	   | Function(_, Function(_)) -> leftex :: rightex :: accu
-	   | _ -> assert false
-	)
-					(* non base case *)
-    | ExprLoc(Application(innerterm, args),_) ->
-	get_args (args :: accu) innerterm
-    | _ ->				(* error no application *)
-	begin
-	  error_message (get_ex_loc left)
-	    ("Wrong form of definition. Expected \"" ^ 
-	     (if mem#get_sort = InfixGroundTerm 
-	      then
-		"x " ^ mem#get_name ^ " y\""
-	      else
-		mem#get_name ^ " ... =\"")
-	    );
-	  raise Resolution_error
-	end
-  in let arg_list_list = get_args [] left in
-			(* pair one argument and one type in a id record *)
-  let make_arg_id typ = function
-    | ExprLoc(BasicExpr(TermVar(Unresolved tok)), vloc) ->
-	let _ =				(* check for doubble occurences *)
-	  try
-	    ignore(Symbol.find_local local_block tok.token_name);
-	    error_message vloc
-	      ("Variables on the left hand side of a defining " ^
-	       "equation must be unique.");
-	    raise Resolution_error
-	  with 
-	    | Table.Not_defined -> ()
-	in 
-	let id_rec = Symbol.identifier_record tok CCSL_Var
-	in
-	  id_rec.id_type <- typ;
-	  Symbol.create_var id_rec;
-	  id_rec
-    | v ->
-	begin
-	  error_message (get_ex_loc v) "Variable expected.";
-	  raise Resolution_error
-	end
-  in
-				(* recursively match arguments and types *)
-  let rec match_args argslist funtype = 
-    let recurse restargs codomain ids =
-      let rest_ids, typ = match_args restargs codomain 
-      in
-	((ids :: rest_ids), typ)
-    in
-      match argslist,funtype with
-	| ExprLoc(Tuple arggroup, loc ) :: restargs, 
-	  Function(Product grouptyp, codomain)
-	  -> 
-	    if List.length grouptyp <> List.length arggroup 
-	    then
-	      begin
-		error_message loc
-		  "Number of arguments does not match type declaration.";
-		raise Resolution_error
-	      end
-	    else
-	      recurse restargs codomain
-		(List.map2 make_arg_id grouptyp arggroup)
-	| (ExprLoc _ as singlearg) :: restargs, 
-	  Function(typ, codomain) ->
-	    recurse restargs codomain [make_arg_id typ singlearg]
-	| _ , Groundtype(idrec, args) when is_type_def idrec ->
-	    (* do not use recurse here, 
-	     * because we ded not produce any binding
-	     *)
-	    match_args argslist (expand_type_def eq_ccsl_types funtype)
-
-	| [], resttyp -> [], resttyp
-	| ExprLoc(_, loc) :: _, _ ->
-	    error_message loc "Superfluous variable.";
-	    raise Resolution_error
-	| _ -> let x = 2 + 2 in
-	    assert false
-
-  in let id_list_list, righttyp = match_args arg_list_list mem#get_full_type
-
-  in let nright = do_expression iface right_loc right
-  in 
-    def.definition <- 
-    Symbolic(FormLoc(Formula( TypeAnnotation(nright, righttyp)),
-		     right_loc));
-    def.variables <- id_list_list;
-    ignore(Symbol.close_block())
-      
-	     
-let do_definition iface def =
-  match def.definition with
-    | Symbolic _ -> do_symbolic_definition iface def
-    | _ -> ()
+(* 
+ * (\* Process a definition in a ground signature or in a class
+ *  * 
+ *  * From the parser the definition comes in as a formula, which 
+ *  * should better be an equation.
+ *  * From the left hand side of the equation I extract variable declarations, 
+ *  * by matching these variables against the declared type.
+ *  * After that the left hand side is thrown away, the extracted variables 
+ *  * are stored in the definition record and the right hand side is wrapped
+ *  * in a TypeAnnotation to remember its supposed type
+ *  *\)
+ * 
+ * let do_symbolic_definition iface def =
+ *   let def_eq = match def.definition with
+ *     | Symbolic eq -> eq
+ *     | _ -> assert(false)
+ *   in let mem = def.defined_method in
+ * 				(\* create the block for this equation *\)
+ *   let local_block = Symbol.start_block() in
+ *   let _ = d ("  * Resolve definition " ^ def.defined_method#get_name) in
+ * 
+ * 					(\* create local type parameters *\)
+ *   let _ = List.iter (function TypeParameter id_rec ->
+ * 		       Symbol.create_type_parameter id_rec) 
+ * 	    mem#get_local_parameters
+ *   in					(\* extract left and right hand sides *\)
+ *   let left, right, right_loc = 
+ *     match def_eq with
+ *       | FormLoc(Equal(left, ExprLoc(right,right_loc)), _)
+ * 	  -> left,right,right_loc
+ *       | _ -> 
+ * 	  begin
+ * 	    error_message (get_form_loc def_eq)
+ * 	      "Definition not in form of an equation.";
+ * 	    raise Resolution_error
+ * 	  end
+ * 		(\* recursively extract variables from the left hand side 
+ * 		 * take care to handle cases like
+ * 		 *   f = ...
+ * 		 *   f x y = ...
+ * 		 *   f (x,y) (a,b) = ...
+ * 		 *   (x + y) (a,b) = ...
+ * 		 *\)
+ *   in let rec get_args accu = function
+ * 					(\* base case normal application *\)
+ *     | ExprLoc(Application(
+ * 		ExprLoc(BasicExpr(TermVar(Unresolved defname)),_),
+ * 		args),_) 
+ * 	when defname.token_name = mem#get_name ->
+ * 	args :: accu
+ * 					(\* base case def =  *\)
+ *     | ExprLoc(BasicExpr(TermVar(Unresolved defname)),_)
+ * 	when defname.token_name = mem#get_name 
+ * 	  ->
+ * 	accu
+ * 					(\* base case with infixes *\)
+ *     | ExprLoc(InfixApplication(leftex, _, Unresolved op, rightex), loc) 
+ * 	when op.token_name = mem#get_name ->
+ * 	(match mem#get_full_type with
+ * 	   | Function(Product [_;_], _) -> 
+ * 	       ExprLoc(Tuple([leftex;rightex]), loc) :: accu
+ * 	   | Function(_, Function(_)) -> leftex :: rightex :: accu
+ * 	   | _ -> assert false
+ * 	)
+ * 					(\* non base case *\)
+ *     | ExprLoc(Application(innerterm, args),_) ->
+ * 	get_args (args :: accu) innerterm
+ *     | _ ->				(\* error no application *\)
+ * 	begin
+ * 	  error_message (get_ex_loc left)
+ * 	    ("Wrong form of definition. Expected \"" ^ 
+ * 	     (if mem#get_sort = InfixGroundTerm 
+ * 	      then
+ * 		"x " ^ mem#get_name ^ " y\""
+ * 	      else
+ * 		mem#get_name ^ " ... =\"")
+ * 	    );
+ * 	  raise Resolution_error
+ * 	end
+ *   in let arg_list_list = get_args [] left in
+ * 			(\* pair one argument and one type in a id record *\)
+ *   let make_arg_id typ = function
+ *     | ExprLoc(BasicExpr(TermVar(Unresolved tok)), vloc) ->
+ * 	let _ =				(\* check for doubble occurences *\)
+ * 	  try
+ * 	    ignore(Symbol.find_local local_block tok.token_name);
+ * 	    error_message vloc
+ * 	      ("Variables on the left hand side of a defining " ^
+ * 	       "equation must be unique.");
+ * 	    raise Resolution_error
+ * 	  with 
+ * 	    | Table.Not_defined -> ()
+ * 	in 
+ * 	let id_rec = Symbol.identifier_record tok CCSL_Var
+ * 	in
+ * 	  id_rec.id_type <- typ;
+ * 	  Symbol.create_var id_rec;
+ * 	  id_rec
+ *     | v ->
+ * 	begin
+ * 	  error_message (get_ex_loc v) "Variable expected.";
+ * 	  raise Resolution_error
+ * 	end
+ *   in
+ * 				(\* recursively match arguments and types *\)
+ *   let rec match_args argslist funtype = 
+ *     let recurse restargs codomain ids =
+ *       let rest_ids, typ = match_args restargs codomain 
+ *       in
+ * 	((ids :: rest_ids), typ)
+ *     in
+ *       match argslist,funtype with
+ * 	| ExprLoc(Tuple arggroup, loc ) :: restargs, 
+ * 	  Function(Product grouptyp, codomain)
+ * 	  -> 
+ * 	    if List.length grouptyp <> List.length arggroup 
+ * 	    then
+ * 	      begin
+ * 		error_message loc
+ * 		  "Number of arguments does not match type declaration.";
+ * 		raise Resolution_error
+ * 	      end
+ * 	    else
+ * 	      recurse restargs codomain
+ * 		(List.map2 make_arg_id grouptyp arggroup)
+ * 	| (ExprLoc _ as singlearg) :: restargs, 
+ * 	  Function(typ, codomain) ->
+ * 	    recurse restargs codomain [make_arg_id typ singlearg]
+ * 	| _ , Groundtype(idrec, args) when is_type_def idrec ->
+ * 	    (\* do not use recurse here, 
+ * 	     * because we ded not produce any binding
+ * 	     *\)
+ * 	    match_args argslist (expand_type_def eq_ccsl_types funtype)
+ * 
+ * 	| [], resttyp -> [], resttyp
+ * 	| ExprLoc(_, loc) :: _, _ ->
+ * 	    error_message loc "Superfluous variable.";
+ * 	    raise Resolution_error
+ * 	| _ -> let x = 2 + 2 in
+ * 	    assert false
+ * 
+ *   in let id_list_list, righttyp = match_args arg_list_list mem#get_full_type
+ * 
+ *   in let nright = do_expression iface right_loc right
+ *   in 
+ *     def.definition <- 
+ *     Symbolic(FormLoc(Formula( TypeAnnotation(nright, righttyp)),
+ * 		     right_loc));
+ *     def.variables <- id_list_list;
+ *     ignore(Symbol.close_block())
+ *       
+ * 	     
+ * let do_definition iface def =
+ *   match def.definition with
+ *     | Symbolic _ -> do_symbolic_definition iface def
+ *     | _ -> ()
+ *)
 
 
 
@@ -773,120 +803,128 @@ let do_definition iface def =
  *
  *)
 
-let do_class ccl = 
-  let nest = Symbol.nesting_size() 
-  in begin
-      d (" ** Resolve class " ^ ccl#get_name);
-      (* d (ccl#dump_iface); *)
-      ignore(Symbol.start_block());
-      (* print_verbose( "Symboltable: " );
-       * print_verbose (Symbol.symbol_table_dump 
-       * 			  Top_variant_types_util.dump_symbol_brief);
-       *)
-
-      List.iter (function TypeParameter id_rec ->
-		   Symbol.create_type_parameter id_rec) ccl#get_parameters;
-      List.iter (fun acl -> List.iter Symbol.create_member
-		     acl#get_all_actions)
-	ccl#get_resolved_ancestors;
-      List.iter Symbol.create_member ccl#get_sig_actions;
-
-      List.iter (fun def -> 
-		   do_definition ccl def;
-		   Symbol.create_member def.defined_method
-		)
-	ccl#get_definitions;
-      assert(Symbol.nesting_size() = nest + 1);
-
-         (* make class specials available in assertions *)
-      List.iter (fun mem -> (if mem#get_sort = Class_Special
-			     then
-			       Symbol.create_member mem)
-		)
-	ccl#get_members;
-
-      (* print_verbose( "Symboltable: " );
-       * print_verbose (Symbol.symbol_table_dump 
-       * 			  Top_variant_types_util.dump_symbol_brief);
-       *)
-
-      List.iter (fun ass -> do_assertion ccl ass) ccl#get_assertions;
-      assert(Symbol.nesting_size() = nest + 1);
-      List.iter (fun mem -> Symbol.create_member mem)
-	ccl#get_constructors;
-      List.iter (fun crea -> do_assertion ccl crea) 
-	ccl#get_creations; 
-      List.iter (fun thm -> do_assertion ccl thm) 
-	ccl#get_theorems; 
-
-      (* print_verbose( "Symboltable: " );
-       * print_verbose (Symbol.symbol_table_dump 
-       * 			  Top_variant_types_util.dump_symbol_brief);
-       *)
-
-      assert(Symbol.nesting_size() = nest + 1);
-      ignore(Symbol.close_block());
-      Symbol.create_class_content ccl
-    end
+(* 
+ * let do_class ccl = 
+ *   let nest = Symbol.nesting_size() 
+ *   in begin
+ *       d (" ** Resolve class " ^ ccl#get_name);
+ *       (\* d (ccl#dump_iface); *\)
+ *       ignore(Symbol.start_block());
+ *       (\* print_verbose( "Symboltable: " );
+ *        * print_verbose (Symbol.symbol_table_dump 
+ *        * 			  Top_variant_types_util.dump_symbol_brief);
+ *        *\)
+ * 
+ *       List.iter (function TypeParameter id_rec ->
+ * 		   Symbol.create_type_parameter id_rec) ccl#get_parameters;
+ *       List.iter (fun acl -> List.iter Symbol.create_member
+ * 		     acl#get_all_actions)
+ * 	ccl#get_resolved_ancestors;
+ *       List.iter Symbol.create_member ccl#get_sig_actions;
+ * 
+ *       List.iter (fun def -> 
+ * 		   do_definition ccl def;
+ * 		   Symbol.create_member def.defined_method
+ * 		)
+ * 	ccl#get_definitions;
+ *       assert(Symbol.nesting_size() = nest + 1);
+ * 
+ *          (\* make class specials available in assertions *\)
+ *       List.iter (fun mem -> (if mem#get_sort = Class_Sig_Special
+ * 			     then
+ * 			       Symbol.create_member mem)
+ * 		)
+ * 	ccl#get_members;
+ * 
+ *       (\* print_verbose( "Symboltable: " );
+ *        * print_verbose (Symbol.symbol_table_dump 
+ *        * 			  Top_variant_types_util.dump_symbol_brief);
+ *        *\)
+ * 
+ *       List.iter (fun ass -> do_assertion ccl ass) ccl#get_assertions;
+ *       assert(Symbol.nesting_size() = nest + 1);
+ *       List.iter (fun mem -> Symbol.create_member mem)
+ * 	ccl#get_constructors;
+ *       List.iter (fun crea -> do_assertion ccl crea) 
+ * 	ccl#get_creations; 
+ *       List.iter (fun thm -> do_assertion ccl thm) 
+ * 	ccl#get_theorems; 
+ * 
+ *       (\* print_verbose( "Symboltable: " );
+ *        * print_verbose (Symbol.symbol_table_dump 
+ *        * 			  Top_variant_types_util.dump_symbol_brief);
+ *        *\)
+ * 
+ *       assert(Symbol.nesting_size() = nest + 1);
+ *       ignore(Symbol.close_block());
+ *       Symbol.create_class_content ccl
+ *     end
+ *)
 
 
-let do_sig si =
-  let nest = Symbol.nesting_size() in
-			(* pair the definitions with the declarations *)
-  let rec pair_consts members definitions =
-    match members,definitions with
-      | [],[] -> []
-      | m::ms,[] ->  (m,None) :: (pair_consts ms definitions)
-      | [], d::_ -> assert(false)
-      | m::ms, d::ds ->
-	  if m == d.defined_method 
-	  then
-	    (m, Some d) :: (pair_consts ms ds)
-	  else
-	    (m, None) :: (pair_consts ms definitions)
-  in
-  let const_list = pair_consts si#get_members si#get_definitions
-  in
-    begin
-      print_verbose ("Resolve signature in " ^ si#get_name );
-      ignore(Symbol.start_block());
-      List.iter (function TypeParameter id_rec ->
-		   Symbol.create_type_parameter id_rec) si#get_parameters;
-
-      List.iter (fun (m,defopt) -> 
-		   (match defopt with
-		      | None -> ()
-		      | Some def -> do_definition si def
-		   );
-
-		   Symbol.create_member m
-		)
-	const_list;
-
-      assert(Symbol.nesting_size() = nest + 1);
-      ignore(Symbol.close_block());
-      Symbol.create_sig_content si
-    end
+(* 
+ * let do_sig si =
+ *   let nest = Symbol.nesting_size() in
+ * 			(\* pair the definitions with the declarations *\)
+ *   let rec pair_consts members definitions =
+ *     match members,definitions with
+ *       | [],[] -> []
+ *       | m::ms,[] ->  (m,None) :: (pair_consts ms definitions)
+ *       | [], d::_ -> assert(false)
+ *       | m::ms, d::ds ->
+ * 	  if m == d.defined_method 
+ * 	  then
+ * 	    (m, Some d) :: (pair_consts ms ds)
+ * 	  else
+ * 	    (m, None) :: (pair_consts ms definitions)
+ *   in
+ *   let const_list = pair_consts si#get_members si#get_definitions
+ *   in
+ *     begin
+ *       d (" ** Resolve signature in " ^ si#get_name );
+ *       ignore(Symbol.start_block());
+ *       List.iter (function TypeParameter id_rec ->
+ * 		   Symbol.create_type_parameter id_rec) si#get_parameters;
+ * 
+ *       List.iter (fun (m,defopt) -> 
+ * 		   (match defopt with
+ * 		      | None -> ()
+ * 		      | Some def -> do_definition si def
+ * 		   );
+ * 
+ * 		   Symbol.create_member m
+ * 		)
+ * 	const_list;
+ * 
+ *       assert(Symbol.nesting_size() = nest + 1);
+ *       ignore(Symbol.close_block());
+ *       Symbol.create_sig_content si
+ *     end
+ *)
 
 
-let do_adt adt =
-  begin
-    print_verbose ("Resolve adt in " 
-		   ^ adt#get_name );
-    Symbol.create_adt_content adt
-  end
+(* 
+ * let do_adt adt =
+ *   begin
+ *     d (" ** Resolve adt in " 
+ * 		   ^ adt#get_name );
+ *     Symbol.create_adt_content adt
+ *   end
+ *)
 
 
-let resolve_ast = function
-  | CCSL_class_dec cl -> do_class cl
-  | CCSL_adt_dec adt -> do_adt adt
-  | CCSL_sig_dec si -> do_sig si
-
-
-let ccsl_resolution_pass (ast: Classtypes.ccsl_ast list) = 
-  let nest = Symbol.nesting_size() in
-    List.iter resolve_ast ast;
-    assert(Symbol.nesting_size() = nest)
+(* 
+ * let resolve_ast = function
+ *   | CCSL_class_dec cl -> do_class cl
+ *   | CCSL_adt_dec adt -> do_adt adt
+ *   | CCSL_sig_dec si -> do_sig si
+ * 
+ * 
+ * let ccsl_resolution_pass (ast: Classtypes.ccsl_ast list) = 
+ *   let nest = Symbol.nesting_size() in
+ *     List.iter resolve_ast ast;
+ *     assert(Symbol.nesting_size() = nest)
+ *)
 
 
 
