@@ -18,23 +18,30 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 18:29:36 tews@debian>
  *
  * Resolution pass for CCSL
  *
- * $Id: resolution.mli,v 1.3 2002/05/03 15:01:13 tews Exp $
+ * $Id: resolution.mli,v 1.4 2003/08/21 15:15:01 tews Exp $
  *
  *)
 
-open Classtypes;;
+open Top_variant_types
+open Classtypes
 
 exception Resolution_error
   
   (* performs updates in the assertions *)
 
-val ccsl_resolution_pass : Classtypes.ccsl_ast list -> unit
+(* val ccsl_resolution_pass : Classtypes.ccsl_ast list -> unit *)
 
 
+val resolve_expression : 
+  ccsl_iface_type -> location_type -> ccsl_expressions -> ccsl_expressions
+
+val resolve_formula : 
+  ccsl_iface_type -> location_type -> ccsl_formulas -> ccsl_formulas
+
 (*** Local Variables: ***)
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
