@@ -18,11 +18,11 @@
  *
  * Created 3.11.99 by Hendrik
  *
- * Time-stamp: <Thursday 4 July 02 18:29:39 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 16:09:08 tews@debian>
  *
  * Semantics
  *
- * $Id: semantics_theory.ml,v 1.16 2002/07/18 13:43:24 tews Exp $
+ * $Id: semantics_theory.ml,v 1.17 2003/08/21 15:15:01 tews Exp $
  *
  *)
 
@@ -304,8 +304,9 @@ class ['class_type, 'member_type] ccsl_pre_semantics_theory
 		| Adt_Const_Constructor
 		| Adt_Var_Constructor 
 		| Adt_Accessor 
-		| Adt_Recognizer | Adt_Reduce 
-		| Class_Coreduce | Class_Special
+		| Adt_Recognizer | Adt_Special 
+		| Class_Coreduce | Class_Map
+		| Class_Sig_Special
 		| GroundTerm | InfixGroundTerm
 		    -> assert(false)
 	   )
@@ -443,9 +444,6 @@ class ['class_type, 'member_type] ccsl_pre_semantics_theory
       @
       [self#do_model] 
 
-(* ISAR
- *     method get_proofs = []
- *)
 end
 
 class ccsl_semantics_theory cl = 
@@ -786,9 +784,6 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
       @
       self#do_creation_lemmas
 
-(* ISAR
- *     method get_proofs = []
- *)
 end
 
 class ccsl_basic_theory cl = 
