@@ -18,11 +18,11 @@
  *
  * Created 25.6.99 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 19:52:45 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Thursday 21 August 03 15:06:33 tews@ithif51.inf.tu-dresden.de>
  *
  * Substitution and class instanciation
  *
- * $Id: substitution.ml,v 1.15 2002/05/22 13:42:43 tews Exp $
+ * $Id: substitution.ml,v 1.16 2003/08/21 15:15:01 tews Exp $
  *
  *)
 
@@ -64,7 +64,8 @@ let rec internal_instanciate iface subst top_args method_filter =
 	  ccsl_substitute_arguments subst args in
 	let inst_anc = internal_instanciate inst_anc subst
 			 subs_args method_filter in
-	let _ = inst#inherit_locals (inst_anc#get_inherited_locals) 
+	let _ = inst#inherit_locals 
+		  (inst_anc#get_local :: inst_anc#get_inherited_locals) 
 	in
 	  (Resolved_renaming(
 	       ancestor,
@@ -101,9 +102,10 @@ let rec internal_instanciate iface subst top_args method_filter =
     | Const_Constructor
     | Adt_Var_Constructor
     | Adt_Const_Constructor
-    | Adt_Reduce
+    | Adt_Special
     | Class_Coreduce
-    | Class_Special
+    | Class_Map
+    | Class_Sig_Special
     | GroundTerm
     | InfixGroundTerm -> ignore( add_member m m#get_sort )
 
