@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Wednesday 24 July 02 16:30:23 tews@ithif51>
+ * Time-stamp: <Wednesday 20 August 03 16:06:41 tews@debian>
  *
  * generic classes for all ccsl class and adt theories
  *
- * $Id: theory_class.ml,v 1.16 2002/09/18 15:35:04 tews Exp $
+ * $Id: theory_class.ml,v 1.17 2003/08/21 15:15:01 tews Exp $
  *
  *)
 
@@ -194,13 +194,16 @@ class virtual ['class_type, 'member_type ] ccsl_pre_theory_body_class
 	      if in_this_class 
 	      then Some algebra_term
 	      else Some top_class#get_model_algebra
-	  | Class_Special -> None
+
+	  | Class_Sig_Special
+	  | Class_Map
+	    -> None
 
 	  | Adt_Var_Constructor
 	  | Adt_Const_Constructor
 	  | Adt_Accessor
 	  | Adt_Recognizer
-	  | Adt_Reduce
+	  | Adt_Special
 	  | GroundTerm
 	  | InfixGroundTerm 
 	    -> assert(false)
@@ -334,11 +337,6 @@ class virtual ['class_type, 'member_type ]
       Predtype(Formula(Term(name_of_assert cl,
  			    Always,self#self1_argument :: orig_arguments)))
 
-(* ISAR
- *     method assert_coalgebra2_type = 
- * 	 Predtype(Formula(Term(name_of_assert cl,
- * 			       Always,self#self2_argument :: orig_arguments)))
- *)
 
       (* This is a bit strange! Since we model the algebra functor
        * as Record of functions (instead of a sum of the domains) the 
@@ -367,14 +365,6 @@ class virtual ['class_type, 'member_type ]
     method assert_coalgebra_decl =
       Vardecl(name_of_coalgebra, self#assert_coalgebra_type)
 
-(* ISAR
- *     method assert_coalgebra1_decl =
- * 	 Vardecl(name_of_coalgebra1, self#assert_coalgebra1_type)
- * 
- *     method assert_coalgebra2_decl =
- * 	 Vardecl(name_of_coalgebra2, self#assert_coalgebra2_type)
- *)
-
       (* the algebra declaration *)
     method algebra_decl = 
       	Vardecl(name_of_algebra, self#algebra_type)
