@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 16:36:05 tews@ithif51>
+ * Time-stamp: <Tuesday 17 December 02 16:46:09 tews@tcs.inf.tu-dresden.de>
  *
  * Utility functions for ccsl input types
  *
- * $Id: types_util.ml,v 1.26 2002/10/28 16:33:19 tews Exp $
+ * $Id: types_util.ml,v 1.28 2003/08/21 15:15:00 tews Exp $
  *
  *)
 
@@ -404,7 +404,7 @@ and unsmart_args args =
  *)
 
 let get_ground_type_parameters idrec = match idrec.id_origin with
-  | CCSL_GroundTypeDef si
+  | CCSL_GroundTypeDef si -> si#get_parameters @ idrec.id_parameters
   | CCSL_GroundTypeDecl si -> si#get_parameters @ idrec.id_parameters
   | _ -> assert(false)
 
@@ -529,6 +529,8 @@ let eq_string (s1 : string) (s2 : string) = s1 = s2
 
 let eq_int (s1 : int) (s2 : int) = s1 = s2
 
+let eq_modal (m1 : top_modality_type) (m2 : top_modality_type) = m1 = m2
+
 let eq_option (eq_fun) o1 o2 = match o1,o2 with
   | Some x1, Some x2 -> eq_fun x1 x2
   | None, _
@@ -655,6 +657,7 @@ and eq_ccsl_formulas f1 f2 = f1 == f2 or match (f1,f2) with
  * 	 (eq_ccsl_expressions ex_a1 ex_a2)
  * 	 && (eq_ccsl_expressions ex_b1 ex_b2)
  *)
+					      (* we are in eq_ccsl_formulas *)
   | Forall(quant_list1, f1),Forall(quant_list2, f2) ->
       (List.length quant_list1 = List.length quant_list2)
       && (List.for_all2 
@@ -678,6 +681,7 @@ and eq_ccsl_formulas f1 f2 = f1 == f2 or match (f1,f2) with
   | MetaImplies(prem1,concl1),MetaImplies(prem2,concl2) ->
       (eq_ccsl_formulas prem1 prem2)
       && (eq_ccsl_formulas concl1 concl2)
+					      (* we are in eq_ccsl_formulas *)
   | MetaForall(quant_list1, f1),MetaForall(quant_list2, f2) ->
       (List.length quant_list1 = List.length quant_list2)
       && (List.for_all2 
@@ -702,6 +706,7 @@ and eq_ccsl_formulas f1 f2 = f1 == f2 or match (f1,f2) with
       && (eq_ccsl_expressions exr1 exr2)
 
   | FormLoc(f1,l), f2 -> eq_ccsl_formulas f1 f2
+					      (* we are in eq_ccsl_formulas *)
   | f1, FormLoc(f2,l) -> eq_ccsl_formulas f1 f2
 
 	(* cases where constructors do not match *)
@@ -724,6 +729,7 @@ and eq_ccsl_formulas f1 f2 = f1 == f2 or match (f1,f2) with
   | Bisim _, _
   | Obseq _, _
 
+					      (* we are in eq_ccsl_formulas *)
 (* double cases
  *   | _, True
  *   | _, False
@@ -806,6 +812,7 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
       	eq_ccsl_expressions obj1 obj2 
       	&& eq_string (m1'#get_name) (m1'#get_name)
 	&& eq_string (m1'#hosting_class#get_name) (m2'#hosting_class#get_name) 
+					    (* we are in eq_ccsl_expressions *)
   | Tuple ex_list1, Tuple ex_list2 ->
       (List.length ex_list1 = List.length ex_list2)
       && (List.for_all2 eq_ccsl_expressions ex_list1 ex_list2)
@@ -838,6 +845,7 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
 			   && eq_ccsl_types typ1 typ2)
 	    decl_list2 decl_list2)
       && (eq_ccsl_expressions ex1 ex2)
+					    (* we are in eq_ccsl_expressions *)
   | SmartAbstraction(decl_list1, ex1), SmartAbstraction(decl_list2, ex2) ->
       (List.length decl_list1 = List.length decl_list2)
       && (List.for_all2 (fun (name1,typ1) (name2,typ2) ->
@@ -869,6 +877,7 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
 			   (eq_ccsl_expressions ex_a1 ex_a2)
 			   && (eq_ccsl_expressions ex_b1 ex_b2))
 	    update_list2 update_list2)
+					    (* we are in eq_ccsl_expressions *)
   | Let(define_list1, ex1), Let(define_list2, ex2) ->
       (List.length define_list1 = List.length define_list2)
       && (List.for_all2 (fun (id1,typ1,ex1) (id2,typ2,ex2) ->
@@ -895,6 +904,7 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
 			   (eq_ccsl_expressions ex_a1 ex_a2)
 			   && (eq_ccsl_expressions ex_b1 ex_b2))
 	    match_list1 match_list2)
+					    (* we are in eq_ccsl_expressions *)
   | CCSL_Case( ex1, match_list1), CCSL_Case( ex2, match_list2) ->
       (eq_ccsl_expressions ex1 ex2)
       && (List.length match_list1 = List.length match_list2)
@@ -913,19 +923,30 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
 		       var_list1 var_list2)
 		 && (eq_ccsl_expressions ex_b1 ex_b2))
 	    match_list1 match_list2)
-  | Box(typ1,pred1,tlist1),
-    Box(typ2,pred2,tlist2) ->
-      (eq_ccsl_types typ1 typ2)
+  | Modality(modal1,typ1,pred1,tlist1),
+    Modality(modal2,typ2,pred2,tlist2) ->
+      (eq_modal modal1 modal2) 
+      && (eq_ccsl_types typ1 typ2)
       && (eq_ccsl_expressions pred1 pred2)
       && (List.for_all2 (fun t1 t2  ->
 			   (eq_string t1.token_name t2.token_name)) 
 	    tlist1 tlist2)
-  | Diamond(typ1,pred1,tlist1),
-    Diamond(typ2,pred2,tlist2) ->
-      (eq_ccsl_types typ1 typ2)
-      && (eq_ccsl_expressions pred1 pred2)
-      && (List.for_all2 (fun t1 t2 -> (eq_string t1.token_name t2.token_name)) 
-	    tlist1 tlist2)
+					    (* we are in eq_ccsl_expressions *)
+  (* 
+   * | Box(typ1,pred1,tlist1),
+   *   Box(typ2,pred2,tlist2) ->
+   *     (eq_ccsl_types typ1 typ2)
+   *     && (eq_ccsl_expressions pred1 pred2)
+   *     && (List.for_all2 (fun t1 t2  ->
+   * 			   (eq_string t1.token_name t2.token_name)) 
+   * 	    tlist1 tlist2)
+   * | Diamond(typ1,pred1,tlist1),
+   *   Diamond(typ2,pred2,tlist2) ->
+   *     (eq_ccsl_types typ1 typ2)
+   *     && (eq_ccsl_expressions pred1 pred2)
+   *     && (List.for_all2 (fun t1 t2 -> (eq_string t1.token_name t2.token_name)) 
+   * 	    tlist1 tlist2)
+   *)
   | Every(typ1, form_list1), Every(typ2, form_list2) ->
       (eq_ccsl_types typ1 typ2) &&
 			(* equal types imply equal parameter lists 
@@ -940,6 +961,7 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
 			 *)
       (assert((List.length form_list1) = (List.length form_list2));
        List.for_all2 eq_ccsl_expressions form_list1 form_list2)
+					    (* we are in eq_ccsl_expressions *)
   | Map(typ1, expr_list1), Map(typ2, expr_list2) ->
       (eq_ccsl_types typ1 typ2) &&
 			(* equal types imply equal parameter lists 
@@ -958,6 +980,8 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
   | ExprLoc(ex1,l), ex2 -> eq_ccsl_expressions ex1 ex2
   | ex1, ExprLoc(ex2,l) -> eq_ccsl_expressions ex1 ex2
 
+					    (* we are in eq_ccsl_expressions *)
+
 	(* and now the cases where the constructors differ *)
   | BasicExpr _,_
   | Term _ ,_
@@ -980,14 +1004,18 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
   | If _ ,_
   | Case _ ,_
   | CCSL_Case _ ,_
-  | Box _,_
-  | Diamond _,_
+  | Modality _,_
+  (* DELETE
+   * | Box _,_
+   * | Diamond _,_
+   *)
   | Every _, _
   | RelEvery _, _
   | Map _, _
   | Expression _ ,_
   | Comprehension _ ,_
 
+					    (* we are in eq_ccsl_expressions *)
   | _, BasicExpr _
   | _, Term _
   | _, TypeAnnotation _
@@ -1009,8 +1037,11 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
   | _, If _
   | _, Case _
   | _, CCSL_Case _
-  | _, Box _
-  | _, Diamond _
+  | _, Modality _
+  (* DELETE
+   * | _, Box _
+   * | _, Diamond _
+   *)
   | _, Every _
   | _, RelEvery _
   | _, Map _
