@@ -18,11 +18,11 @@
  *
  * Created 2.5.02 by Hendrik
  *
- * Time-stamp: <Friday 3 May 02 10:19:39 tews@ithif51>
+ * Time-stamp: <Thursday 21 August 03 17:05:28 tews@ithif51.inf.tu-dresden.de>
  *
  * part of global.ml that is configurable
  *
- * $Id: config.ml,v 1.3 2002/07/18 13:43:26 tews Exp $
+ * $Id: config.ml,v 1.5 2003/08/21 15:14:59 tews Exp $
  *
  *)
 
@@ -32,8 +32,11 @@
  * Should be the same as LIBDIR in ../Makefile.
  *)
 
-let fixedpointlib = "/home/tews/Privat/tmp/Ccslc/Lib/Pvs"
-
+(* USE prelude gfp now
+ * 
+ * let fixedpointlib = "/sun/theorie/tews/Privat/Coda/Work2/Lib/Pvs"
+ * 
+ *)
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
