@@ -18,11 +18,11 @@
  *
  * Created 2.5.02 by Hendrik
  *
- * Time-stamp: <Monday 11 March 02 11:39:35 tews@ithif51>
+ * Time-stamp: <Wednesday 30 July 03 15:27:50 tews@ithif51.inf.tu-dresden.de>
  *
  * part of global.ml that is configurable
  *
- * $Id: config.mli,v 1.2 2002/05/03 15:01:16 tews Exp $
+ * $Id: config.mli,v 1.3 2003/08/21 15:14:59 tews Exp $
  *
  *)
 
@@ -31,8 +31,11 @@
     (* the path for the fixedpoints library
      *)
 
-val fixedpointlib : string
-
+(* USE prelude gfp now
+ * 
+ * val fixedpointlib : string
+ * 
+ *)
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
