@@ -18,11 +18,11 @@
  *
  * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 17:10:30 tews@ithif51>
+ * Time-stamp: <Wednesday 30 July 03 15:28:57 tews@ithif51.inf.tu-dresden.de>
  *
  * global control variables of the loop compiler
  *
- * $Id: global.ml,v 1.20 2002/10/28 16:33:20 tews Exp $
+ * $Id: global.ml.in,v 1.2 2003/08/21 15:14:58 tews Exp $
  *
  *)
 
@@ -39,7 +39,7 @@ open Top_variant_types
  *)
 
 
-let compiler_version = "CCSL Compiler Version 2.2 pl 1"
+let compiler_version = "CCSL Compiler Version 2.2.6"
 
 
 (***********************************************************************
@@ -210,6 +210,15 @@ let inline_liftings = ref true
 let dependent_assertions = ref false
 
 
+    (*
+     * backward compatible prelude: Lift with bot
+     *
+     * set via -old-lift
+     *)
+let old_lift = ref false
+
+
+
 (***********************************************************************
  ***********************************************************************
  *
@@ -318,14 +327,16 @@ let set_nat_type name = nat_type_ref := name
 let get_nat_type () = !nat_type_ref
 
 
-    (* the path for the fixedpoints library
-     *)
-
-let fixedpointlib = ref Config.fixedpointlib
-
-let set_pvs_ccsl_lib_location loc = fixedpointlib := loc
-
-let get_pvs_ccsl_lib_location () = !fixedpointlib
+(* USE prelude gfp now
+ *     (\* the path for the fixedpoints library
+ *      *\)
+ * 
+ * let fixedpointlib = ref Config.fixedpointlib
+ * 
+ * let set_pvs_ccsl_lib_location loc = fixedpointlib := loc
+ * 
+ * let get_pvs_ccsl_lib_location () = !fixedpointlib
+ *)
 
 
 (*******************************************************************
