@@ -18,11 +18,11 @@
  *
  * Created 26.2.99 by Joachim
  *
- * Time-stamp: <Monday 15 July 02 17:23:26 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 13:37:34 tews@debian>
  *
  * Isar pretty printer
  *
- * $Id: isar_pretty.ml,v 1.2 2002/07/18 13:43:26 tews Exp $
+ * $Id: isar_pretty.ml,v 1.3 2003/08/21 15:14:58 tews Exp $
  *
  *)
 
@@ -752,9 +752,12 @@ and isar_pp_top_expression
 					(* washed away in a pre-pass! *)
     | Projection _ 
     | MethodSelection _
-    | Box _
-    | Diamond _ ->
-      	assert(false)
+    | Modality _
+    (* DELETE
+     * | Box _
+     * | Diamond _ 
+     *)
+      -> assert(false)
 	
 
 	
