@@ -18,11 +18,11 @@
  *
  * Created 11.11.99 by Hendrik
  *
- * Time-stamp: <Monday 28 October 02 14:47:22 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 13:37:29 tews@debian>
  *
  * substitution and optimization for top_types
  *
- * $Id: logic_util.ml,v 1.24 2002/10/28 16:33:20 tews Exp $
+ * $Id: logic_util.ml,v 1.25 2003/08/21 15:14:58 tews Exp $
  *
  *)
 
@@ -473,18 +473,26 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if ex == nex && variants == nvariants 
 		 then expr
 		 else CCSL_Case(nex, nvariants)
-	   | Box(typ,pred,tlist) ->
+	   | Modality(modal,typ,pred,tlist) ->
 	       let n_typ =  recurse_type typ in
 	       let n_pred = recurse_exp pred in
 		 if n_typ == typ && n_pred == pred then
 		   expr
-		 else Box(n_typ,n_pred,tlist)
-	   | Diamond(typ,pred,tlist) ->
-	       let n_typ =  recurse_type typ in
-	       let n_pred = recurse_exp pred in
-		 if n_typ == typ && n_pred == pred then
-		   expr
-		 else Diamond(n_typ,n_pred,tlist)
+		 else Modality(modal,n_typ,n_pred,tlist)
+	   (* DELETE
+            * | Box(typ,pred,tlist) ->
+	    *     let n_typ =  recurse_type typ in
+	    *     let n_pred = recurse_exp pred in
+	    * 	 if n_typ == typ && n_pred == pred then
+	    * 	   expr
+	    * 	 else Box(n_typ,n_pred,tlist)
+	    * | Diamond(typ,pred,tlist) ->
+	    *     let n_typ =  recurse_type typ in
+	    *     let n_pred = recurse_exp pred in
+	    * 	 if n_typ == typ && n_pred == pred then
+	    * 	   expr
+	    * 	 else Diamond(n_typ,n_pred,tlist)
+            *)
 					  (* we are in substitute_expression *)
 	   | Every(typ, form_list) -> 
 	       let ntyp = recurse_type typ in
@@ -710,6 +718,7 @@ let rec occurs_free_in_expression id expr =
 	   (recurse_exp ex) or
 	   (List.exists (fun (label,ex) -> recurse_exp ex) changes)
        | List(ex_list) -> List.exists recurse_exp ex_list
+				      (* we are in occurs_free_in_expression *)
        | Abstraction(decl_list,ex) ->
 	   if List.exists (fun (v,typ) -> v = id) decl_list
 	   then				(* id is bound *)
@@ -743,6 +752,7 @@ let rec occurs_free_in_expression id expr =
 		  (recurse_exp lex) or res
 	     )
 	     decl_list (recurse_exp ex)
+				      (* we are in occurs_free_in_expression *)
        | If(conds,ex) ->
 	   (List.exists (fun (cond,ex) -> 
 			   (recurse_form cond) or recurse_exp ex)
@@ -773,8 +783,12 @@ let rec occurs_free_in_expression id expr =
 		   recurse_exp case
 	      )
 	      variants)
-       | Box(typ,pred,tlist) -> recurse_exp pred
-       | Diamond(typ,pred,tlist) -> recurse_exp pred
+				      (* we are in occurs_free_in_expression *)
+       | Modality(modal,typ,pred,tlist) -> recurse_exp pred
+       (* DELETE
+        * | Box(typ,pred,tlist) -> recurse_exp pred
+        * | Diamond(typ,pred,tlist) -> recurse_exp pred
+        *)
        | Every(typ, pred_list) -> 
 	   List.exists recurse_exp pred_list
        | RelEvery(typ, pred_list) -> 
