@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 19 August 03 23:10:40 tews@debian>
  *
  * generate batch file for pvs or Isabelle
  *
- * $Id: pvs_batch.ml,v 1.6 2002/05/03 15:01:18 tews Exp $
+ * $Id: pvs_batch.ml,v 1.7 2003/08/21 15:14:58 tews Exp $
  *
  *)
 
@@ -79,7 +79,7 @@ let output_pvs_batch name =
          \n\
 	(setq current-prefix-arg t) \n\
 	(mapcar (lambda (f) \n\
-	     \t(message (concat \"\\n--> Typechecking \" f)) \n\
+	     \t(message (concat \"\\n--> Typechecking \" f \"\\n\")) \n\
 	     \t(typecheck f) \n\
 	     \t;(prove-pvs-file f) \n\
 	     \t) \n\
