@@ -18,11 +18,11 @@
  *
  * Created 26.2.99 by Bart
  *
- * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
+ * Time-stamp: <Tuesday 22 July 03 13:37:29 tews@debian>
  *
  * PVS pretty printer
  *
- * $Id: pvs_pretty.ml,v 1.23 2002/07/18 13:43:27 tews Exp $
+ * $Id: pvs_pretty.ml,v 1.24 2003/08/21 15:14:58 tews Exp $
  *
  *)
 
@@ -631,21 +631,7 @@ and pvs_pp_top_expression (* : top_expressions -> unit *)
 		 print_space();
 		 close_box()				   (* 1 *)
 	       end)
-(*     | Reduce (adt, flag, arg_list) ->
- * 	   begin
- * 	     open_box 0;
- * 	     print_string (name_of_adt_reduce adt);
- * 	     if ( arg_list <> [] ) && (flag = Always )
- * 	     then
- * 	       begin
- * 		 print_string "[";
- * 		 pvs_pp_arg_list arg_list;
- * 		 print_string "]";
- * 		 print_break 0 2
- * 	       end;
- * 	     close_box()
- * 	   end
- *)
+
     | Every (typ, expr_list) ->
 	let every_term = 
 			(* every is only defined for three kinds of types *)
@@ -746,9 +732,12 @@ and pvs_pp_top_expression (* : top_expressions -> unit *)
 					(* washed away in a pre-pass! *)
     | Projection _ 
     | MethodSelection _
-    | Box _
-    | Diamond _ ->
-      	assert(false)
+    | Modality _
+    (* DELETE
+     * | Box _
+     * | Diamond _ 
+     *)
+	-> assert(false)
 
 	
 and pvs_pp_top_formula (* : top_formulas -> unit *)
