@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Saturday 11 May 02 19:24:32 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Saturday 25 May 02 1:07:36 tews@ithif56.inf.tu-dresden.de>
  *
  * utility functions for pvs proofs
  *
- * $Id: pvs_proof_util.mli,v 1.4 2002/05/22 13:42:46 tews Exp $
+ * $Id: pvs_proof_util.mli,v 1.5 2002/05/30 13:10:32 tews Exp $
  *
  *)
 
@@ -58,6 +58,9 @@ val expand : string -> lisp_expr
 
 val expand_num : string -> int -> lisp_expr
 
+    (* (EXPAND* .... ) *)
+val expand_star : string list -> lisp_expr
+
 val extensionality : lisp_expr
 
 val fail : lisp_expr
@@ -78,6 +81,9 @@ val induct : string -> lisp_expr
     (* (SKOLEM!) *)
 val skolem_bang : lisp_expr
 
+    (* (SKOLEM-TYPEPRED) *)
+val skolem_typepred : lisp_expr
+
     (* (INST?) *)
 val inst_question : lisp_expr
 
@@ -103,6 +109,8 @@ val postpone : lisp_expr
 
 val reduce : lisp_expr
 
+val replace_eta : string -> lisp_expr
+
 val replace_num : int -> lisp_expr
 
 val branch : lisp_expr -> lisp_expr list -> lisp_expr
