@@ -18,11 +18,11 @@
  *
  * Created 26.6.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 18:34:41 tews@ithif51>
  *
  * string representation for items used in both translations, 
  *
- * $Id: top_names.ml,v 1.7 2002/05/03 15:01:19 tews Exp $
+ * $Id: top_names.ml,v 1.8 2002/07/18 13:43:28 tews Exp $
  *
  *)
 
@@ -39,7 +39,7 @@ let name_of_isa_batch = "ROOT.ML"
  *)
 
 (* *)
-let isabelle_top_theory = "CCSLMain"
+let isabelle_top_theory = "Main"
 (* *)
 
 let name_of_method_functor cl = cl#get_name ^ "Signature"
@@ -102,7 +102,7 @@ let name_of_const_map tc =
 let name_of_greatest_bisim cl =
   match !output_mode with
     | Pvs_mode -> "bisim?"
-    | Isa_mode -> "bibisim"
+    | Isa_mode -> cl#get_name ^ "_bibisim"
 
 let name_of_final_coalgebra cl = cl#get_name ^"_c"
 
