@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Bart
  *
- * Time-stamp: <Monday 15 July 02 15:11:29 tews@ithif51>
+ * Time-stamp: <Thursday 21 August 03 13:26:01 tews@ithif51.inf.tu-dresden.de>
  *
  * top level type definitions
  *
- * $Id: top_variant_types.ml,v 1.27 2002/07/18 13:43:28 tews Exp $
+ * $Id: top_variant_types.ml,v 1.29 2003/08/21 15:14:57 tews Exp $
  *
  *)
 
@@ -240,9 +240,10 @@ type 'mem top_pre_member_sort =
   | Adt_Const_Constructor		(* adt constructor without args *)
   | Adt_Accessor			(* an accessor *)
   | Adt_Recognizer			(* an recognizer *)
-  | Adt_Reduce
+  | Adt_Special				(* reduce / map *)
   | Class_Coreduce
-  | Class_Special			(* morphism? and friends *)
+  | Class_Map
+  | Class_Sig_Special			(* morphism? and friends *)
   | GroundTerm				(* member of a ground signature *)
   | InfixGroundTerm			(* infix GroundTerm *)
 
@@ -276,6 +277,10 @@ type top_spec_kind =
   | Spec_sig
 
 
+type top_modality_type =
+  | Henceforth			    (* Always is already used as constructor *)
+  | Eventually
+
 
 type import = string
 
@@ -503,15 +508,23 @@ and ('cl, 'mem) top_pre_expressions =
        *  + the predicate they are talking about ('cl,'mem) top_pre_expressions
        *  + the list of considered methods
        * 
-       * VALID_CLASS Sidecondition applies to first argument of Box and Diamond
+       * VALID_CLASS Sidecondition applies to second 
+       * argument of Box and Diamond
        *)
-  | Box of
-      ('cl, 'mem) top_pre_types *
-      ('cl, 'mem) top_pre_expressions * token_type list
-  | Diamond of
+  | Modality of
+      top_modality_type *
       ('cl, 'mem) top_pre_types *
       ('cl, 'mem) top_pre_expressions * token_type list
 
+  (* DELETE
+   * | Box of
+   *     ('cl, 'mem) top_pre_types *
+   *     ('cl, 'mem) top_pre_expressions * token_type list
+   * | Diamond of
+   *     ('cl, 'mem) top_pre_types *
+   *     ('cl, 'mem) top_pre_expressions * token_type list
+   *)
+
       (* symbolic predicate lifting for adt's, classes, TypeConstants 
        *
        * in Every(typ, pred_list)
@@ -611,6 +624,11 @@ and ('cl, 'mem) top_pre_assertion_record =
  *    f a (b,c) d = ....
  * gives rise to the following variable list
  * 	[ [a]; [b,c], d]
+ *
+ * The sequence number records the order of constants and types in 
+ * ground signatures. They are sorted in the backend with the 
+ * sequence number.  
+ * 
  *)
 
 and ('cl, 'mem) top_pre_definition_record =
@@ -749,6 +767,12 @@ and ('cl, 'mem) top_pre_origin_type =
   | CCSL_Output				(* everything irrelvant 
 					   except the name *)
 
+
+(* 
+ * The id_sequence records the order with definitions in ground 
+ * signatures. See also def_sequence.
+ *)
+
 and ('cl, 'mem) top_pre_identifier_record_type =
   { 
     id_token  : token_type;
@@ -791,11 +815,6 @@ type ('cl, 'mem) top_pre_renaming =
  * depend on them
  *)
 type ('cl, 'mem) top_pre_ancestor_type =
-(* DELETE
- * no java ancestors
- *   | Unresolved_ancestor of token_type list
- *   | Resolved_ancestor of 'cl
- *)
   | Unresolved_renaming of
       'cl *     (* the original class *)
       ('cl, 'mem) top_pre_argument_type list *
